# Pipedrive OpenAPI Ruby Client

Pipedrive - a Ruby client for Pipedrive's API v1

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pipedrive-openapi-client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pipedrive-openapi-client-1.0.0.gem
```

(for development, run `gem install --dev ./pipedrive-openapi-client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pipedrive-openapi-client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pipedrive-openapi-client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pipedrive-openapi-client'

# Setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ActivitiesApi.new
ids = 'ids_example' # String | Comma-separated IDs that will be deleted

begin
  #Delete multiple activities in bulk
  api_instance.activities_delete(ids)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ActivitiesApi->activities_delete: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.pipedrive.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Pipedrive::ActivitiesApi* | [**activities_delete**](docs/ActivitiesApi.md#activities_delete) | **DELETE** /activities | Delete multiple activities in bulk
*Pipedrive::ActivitiesApi* | [**activities_get**](docs/ActivitiesApi.md#activities_get) | **GET** /activities | Get all activities assigned to a particular user
*Pipedrive::ActivitiesApi* | [**activities_id_delete**](docs/ActivitiesApi.md#activities_id_delete) | **DELETE** /activities/{id} | Delete an activity
*Pipedrive::ActivitiesApi* | [**activities_id_get**](docs/ActivitiesApi.md#activities_id_get) | **GET** /activities/{id} | Get details of an activity
*Pipedrive::ActivitiesApi* | [**activities_id_put**](docs/ActivitiesApi.md#activities_id_put) | **PUT** /activities/{id} | Edit an activity
*Pipedrive::ActivitiesApi* | [**activities_post**](docs/ActivitiesApi.md#activities_post) | **POST** /activities | Add an activity
*Pipedrive::ActivityFieldsApi* | [**activity_fields_get**](docs/ActivityFieldsApi.md#activity_fields_get) | **GET** /activityFields | Get all fields for an activity
*Pipedrive::ActivityTypesApi* | [**activity_types_delete**](docs/ActivityTypesApi.md#activity_types_delete) | **DELETE** /activityTypes | Delete multiple activity types in bulk
*Pipedrive::ActivityTypesApi* | [**activity_types_get**](docs/ActivityTypesApi.md#activity_types_get) | **GET** /activityTypes | Get all activity types
*Pipedrive::ActivityTypesApi* | [**activity_types_id_delete**](docs/ActivityTypesApi.md#activity_types_id_delete) | **DELETE** /activityTypes/{id} | Delete an activity type
*Pipedrive::ActivityTypesApi* | [**activity_types_id_put**](docs/ActivityTypesApi.md#activity_types_id_put) | **PUT** /activityTypes/{id} | Edit activity type
*Pipedrive::ActivityTypesApi* | [**activity_types_post**](docs/ActivityTypesApi.md#activity_types_post) | **POST** /activityTypes | Add new activity type
*Pipedrive::CallLogsApi* | [**call_logs_get**](docs/CallLogsApi.md#call_logs_get) | **GET** /callLogs | Get all call logs assigned to a particular user
*Pipedrive::CallLogsApi* | [**call_logs_id_delete**](docs/CallLogsApi.md#call_logs_id_delete) | **DELETE** /callLogs/{id} | Delete a call log
*Pipedrive::CallLogsApi* | [**call_logs_id_get**](docs/CallLogsApi.md#call_logs_id_get) | **GET** /callLogs/{id} | Get details of a call log
*Pipedrive::CallLogsApi* | [**call_logs_id_recordings_post**](docs/CallLogsApi.md#call_logs_id_recordings_post) | **POST** /callLogs/{id}/recordings | Attach an audio file to the call log
*Pipedrive::CallLogsApi* | [**call_logs_post**](docs/CallLogsApi.md#call_logs_post) | **POST** /callLogs | Add a call log
*Pipedrive::CurrenciesApi* | [**currencies_get**](docs/CurrenciesApi.md#currencies_get) | **GET** /currencies | Get all supported currencies
*Pipedrive::DealFieldsApi* | [**deal_fields_delete**](docs/DealFieldsApi.md#deal_fields_delete) | **DELETE** /dealFields | Delete multiple deal fields in bulk
*Pipedrive::DealFieldsApi* | [**deal_fields_get**](docs/DealFieldsApi.md#deal_fields_get) | **GET** /dealFields | Get all deal fields
*Pipedrive::DealFieldsApi* | [**deal_fields_id_delete**](docs/DealFieldsApi.md#deal_fields_id_delete) | **DELETE** /dealFields/{id} | Delete a deal field
*Pipedrive::DealFieldsApi* | [**deal_fields_id_get**](docs/DealFieldsApi.md#deal_fields_id_get) | **GET** /dealFields/{id} | Get one deal field
*Pipedrive::DealFieldsApi* | [**deal_fields_id_put**](docs/DealFieldsApi.md#deal_fields_id_put) | **PUT** /dealFields/{id} | Update a deal field
*Pipedrive::DealFieldsApi* | [**deal_fields_post**](docs/DealFieldsApi.md#deal_fields_post) | **POST** /dealFields | Add a new deal field
*Pipedrive::DealsApi* | [**deals_delete**](docs/DealsApi.md#deals_delete) | **DELETE** /deals | Delete multiple deals in bulk
*Pipedrive::DealsApi* | [**deals_find_get**](docs/DealsApi.md#deals_find_get) | **GET** /deals/find | Find deals by name
*Pipedrive::DealsApi* | [**deals_get**](docs/DealsApi.md#deals_get) | **GET** /deals | Get all deals
*Pipedrive::DealsApi* | [**deals_id_activities_get**](docs/DealsApi.md#deals_id_activities_get) | **GET** /deals/{id}/activities | List activities associated with a deal
*Pipedrive::DealsApi* | [**deals_id_delete**](docs/DealsApi.md#deals_id_delete) | **DELETE** /deals/{id} | Delete a deal
*Pipedrive::DealsApi* | [**deals_id_duplicate_post**](docs/DealsApi.md#deals_id_duplicate_post) | **POST** /deals/{id}/duplicate | Duplicate deal
*Pipedrive::DealsApi* | [**deals_id_files_get**](docs/DealsApi.md#deals_id_files_get) | **GET** /deals/{id}/files | List files attached to a deal
*Pipedrive::DealsApi* | [**deals_id_flow_get**](docs/DealsApi.md#deals_id_flow_get) | **GET** /deals/{id}/flow | List updates about a deal
*Pipedrive::DealsApi* | [**deals_id_followers_follower_id_delete**](docs/DealsApi.md#deals_id_followers_follower_id_delete) | **DELETE** /deals/{id}/followers/{follower_id} | Delete a follower from a deal
*Pipedrive::DealsApi* | [**deals_id_followers_get**](docs/DealsApi.md#deals_id_followers_get) | **GET** /deals/{id}/followers | List followers of a deal
*Pipedrive::DealsApi* | [**deals_id_followers_post**](docs/DealsApi.md#deals_id_followers_post) | **POST** /deals/{id}/followers | Add a follower to a deal
*Pipedrive::DealsApi* | [**deals_id_get**](docs/DealsApi.md#deals_id_get) | **GET** /deals/{id} | Get details of a deal
*Pipedrive::DealsApi* | [**deals_id_mail_messages_get**](docs/DealsApi.md#deals_id_mail_messages_get) | **GET** /deals/{id}/mailMessages | List mail messages associated with a deal
*Pipedrive::DealsApi* | [**deals_id_merge_put**](docs/DealsApi.md#deals_id_merge_put) | **PUT** /deals/{id}/merge | Merge two deals
*Pipedrive::DealsApi* | [**deals_id_participants_deal_participant_id_delete**](docs/DealsApi.md#deals_id_participants_deal_participant_id_delete) | **DELETE** /deals/{id}/participants/{deal_participant_id} | Delete a participant from a deal
*Pipedrive::DealsApi* | [**deals_id_participants_get**](docs/DealsApi.md#deals_id_participants_get) | **GET** /deals/{id}/participants | List participants of a deal
*Pipedrive::DealsApi* | [**deals_id_participants_post**](docs/DealsApi.md#deals_id_participants_post) | **POST** /deals/{id}/participants | Add a participant to a deal
*Pipedrive::DealsApi* | [**deals_id_permitted_users_get**](docs/DealsApi.md#deals_id_permitted_users_get) | **GET** /deals/{id}/permittedUsers | List permitted users
*Pipedrive::DealsApi* | [**deals_id_persons_get**](docs/DealsApi.md#deals_id_persons_get) | **GET** /deals/{id}/persons | List all persons associated with a deal
*Pipedrive::DealsApi* | [**deals_id_products_get**](docs/DealsApi.md#deals_id_products_get) | **GET** /deals/{id}/products | List products attached to a deal
*Pipedrive::DealsApi* | [**deals_id_products_post**](docs/DealsApi.md#deals_id_products_post) | **POST** /deals/{id}/products | Add a product to the deal, eventually creating a new item called a deal-product
*Pipedrive::DealsApi* | [**deals_id_products_product_attachment_id_delete**](docs/DealsApi.md#deals_id_products_product_attachment_id_delete) | **DELETE** /deals/{id}/products/{product_attachment_id} | Delete an attached product from a deal
*Pipedrive::DealsApi* | [**deals_id_products_product_attachment_id_put**](docs/DealsApi.md#deals_id_products_product_attachment_id_put) | **PUT** /deals/{id}/products/{product_attachment_id} | Update product attachment details of the deal-product (a product already attached to a deal)
*Pipedrive::DealsApi* | [**deals_id_put**](docs/DealsApi.md#deals_id_put) | **PUT** /deals/{id} | Update a deal
*Pipedrive::DealsApi* | [**deals_post**](docs/DealsApi.md#deals_post) | **POST** /deals | Add a deal
*Pipedrive::DealsApi* | [**deals_search_get**](docs/DealsApi.md#deals_search_get) | **GET** /deals/search | Search deals
*Pipedrive::DealsApi* | [**deals_summary_get**](docs/DealsApi.md#deals_summary_get) | **GET** /deals/summary | Get deals summary
*Pipedrive::DealsApi* | [**deals_timeline_get**](docs/DealsApi.md#deals_timeline_get) | **GET** /deals/timeline | Get deals timeline
*Pipedrive::FilesApi* | [**files_get**](docs/FilesApi.md#files_get) | **GET** /files | Get all files
*Pipedrive::FilesApi* | [**files_id_delete**](docs/FilesApi.md#files_id_delete) | **DELETE** /files/{id} | Delete a file
*Pipedrive::FilesApi* | [**files_id_download_get**](docs/FilesApi.md#files_id_download_get) | **GET** /files/{id}/download | Download one file
*Pipedrive::FilesApi* | [**files_id_get**](docs/FilesApi.md#files_id_get) | **GET** /files/{id} | Get one file
*Pipedrive::FilesApi* | [**files_id_put**](docs/FilesApi.md#files_id_put) | **PUT** /files/{id} | Update file details
*Pipedrive::FilesApi* | [**files_post**](docs/FilesApi.md#files_post) | **POST** /files | Add file
*Pipedrive::FilesApi* | [**files_remote_link_post**](docs/FilesApi.md#files_remote_link_post) | **POST** /files/remoteLink | Link a remote file to an item
*Pipedrive::FilesApi* | [**files_remote_post**](docs/FilesApi.md#files_remote_post) | **POST** /files/remote | Create a remote file and link it to an item
*Pipedrive::FiltersApi* | [**filters_delete**](docs/FiltersApi.md#filters_delete) | **DELETE** /filters | Delete multiple filters in bulk
*Pipedrive::FiltersApi* | [**filters_get**](docs/FiltersApi.md#filters_get) | **GET** /filters | Get all filters
*Pipedrive::FiltersApi* | [**filters_helpers_get**](docs/FiltersApi.md#filters_helpers_get) | **GET** /filters/helpers | Get all filter helpers
*Pipedrive::FiltersApi* | [**filters_id_delete**](docs/FiltersApi.md#filters_id_delete) | **DELETE** /filters/{id} | Delete a filter
*Pipedrive::FiltersApi* | [**filters_id_get**](docs/FiltersApi.md#filters_id_get) | **GET** /filters/{id} | Get one filter
*Pipedrive::FiltersApi* | [**filters_id_put**](docs/FiltersApi.md#filters_id_put) | **PUT** /filters/{id} | Update filter
*Pipedrive::FiltersApi* | [**filters_post**](docs/FiltersApi.md#filters_post) | **POST** /filters | Add a new filter
*Pipedrive::GlobalMessagesApi* | [**global_messages_get**](docs/GlobalMessagesApi.md#global_messages_get) | **GET** /globalMessages | Get global messages
*Pipedrive::GlobalMessagesApi* | [**global_messages_id_delete**](docs/GlobalMessagesApi.md#global_messages_id_delete) | **DELETE** /globalMessages/{id} | Dismiss a global message
*Pipedrive::GoalsApi* | [**goals_find_get**](docs/GoalsApi.md#goals_find_get) | **GET** /goals/find | Find goals
*Pipedrive::GoalsApi* | [**goals_id_delete**](docs/GoalsApi.md#goals_id_delete) | **DELETE** /goals/{id} | Delete existing goal
*Pipedrive::GoalsApi* | [**goals_id_put**](docs/GoalsApi.md#goals_id_put) | **PUT** /goals/{id} | Update existing goal
*Pipedrive::GoalsApi* | [**goals_id_results_get**](docs/GoalsApi.md#goals_id_results_get) | **GET** /goals/{id}/results | Get result of a goal
*Pipedrive::GoalsApi* | [**goals_post**](docs/GoalsApi.md#goals_post) | **POST** /goals | Add a new goal
*Pipedrive::ItemSearchApi* | [**item_search_field_get**](docs/ItemSearchApi.md#item_search_field_get) | **GET** /itemSearch/field | Perform a search using a specific field from an item type
*Pipedrive::ItemSearchApi* | [**item_search_get**](docs/ItemSearchApi.md#item_search_get) | **GET** /itemSearch | Perform a search from multiple item types
*Pipedrive::LeadsApi* | [**lead_labels_get**](docs/LeadsApi.md#lead_labels_get) | **GET** /leadLabels | Get all lead labels
*Pipedrive::LeadsApi* | [**lead_labels_id_delete**](docs/LeadsApi.md#lead_labels_id_delete) | **DELETE** /leadLabels/{id} | Delete a lead label
*Pipedrive::LeadsApi* | [**lead_labels_id_get**](docs/LeadsApi.md#lead_labels_id_get) | **GET** /leadLabels/{id} | Get one lead label
*Pipedrive::LeadsApi* | [**lead_labels_id_patch**](docs/LeadsApi.md#lead_labels_id_patch) | **PATCH** /leadLabels/{id} | Update a lead label
*Pipedrive::LeadsApi* | [**lead_labels_post**](docs/LeadsApi.md#lead_labels_post) | **POST** /leadLabels | Add a lead label
*Pipedrive::LeadsApi* | [**lead_sources_get**](docs/LeadsApi.md#lead_sources_get) | **GET** /leadSources | Get all lead sources
*Pipedrive::LeadsApi* | [**leads_get**](docs/LeadsApi.md#leads_get) | **GET** /leads | Get all leads
*Pipedrive::LeadsApi* | [**leads_id_delete**](docs/LeadsApi.md#leads_id_delete) | **DELETE** /leads/{id} | Delete a lead
*Pipedrive::LeadsApi* | [**leads_id_get**](docs/LeadsApi.md#leads_id_get) | **GET** /leads/{id} | Get one lead
*Pipedrive::LeadsApi* | [**leads_id_patch**](docs/LeadsApi.md#leads_id_patch) | **PATCH** /leads/{id} | Update a lead
*Pipedrive::LeadsApi* | [**leads_post**](docs/LeadsApi.md#leads_post) | **POST** /leads | Add a lead
*Pipedrive::MailMessagesApi* | [**mailbox_mail_messages_id_get**](docs/MailMessagesApi.md#mailbox_mail_messages_id_get) | **GET** /mailbox/mailMessages/{id} | Get one mail message
*Pipedrive::MailThreadsApi* | [**mailbox_mail_threads_get**](docs/MailThreadsApi.md#mailbox_mail_threads_get) | **GET** /mailbox/mailThreads | Get mail threads
*Pipedrive::MailThreadsApi* | [**mailbox_mail_threads_id_delete**](docs/MailThreadsApi.md#mailbox_mail_threads_id_delete) | **DELETE** /mailbox/mailThreads/{id} | Delete mail thread
*Pipedrive::MailThreadsApi* | [**mailbox_mail_threads_id_get**](docs/MailThreadsApi.md#mailbox_mail_threads_id_get) | **GET** /mailbox/mailThreads/{id} | Get one mail thread
*Pipedrive::MailThreadsApi* | [**mailbox_mail_threads_id_mail_messages_get**](docs/MailThreadsApi.md#mailbox_mail_threads_id_mail_messages_get) | **GET** /mailbox/mailThreads/{id}/mailMessages | Get all mail messages of mail thread
*Pipedrive::MailThreadsApi* | [**mailbox_mail_threads_id_put**](docs/MailThreadsApi.md#mailbox_mail_threads_id_put) | **PUT** /mailbox/mailThreads/{id} | Update mail thread details
*Pipedrive::NoteFieldsApi* | [**note_fields_get**](docs/NoteFieldsApi.md#note_fields_get) | **GET** /noteFields | Get all fields for a note
*Pipedrive::NotesApi* | [**notes_get**](docs/NotesApi.md#notes_get) | **GET** /notes | Get all notes
*Pipedrive::NotesApi* | [**notes_id_delete**](docs/NotesApi.md#notes_id_delete) | **DELETE** /notes/{id} | Delete a note
*Pipedrive::NotesApi* | [**notes_id_get**](docs/NotesApi.md#notes_id_get) | **GET** /notes/{id} | Get one note
*Pipedrive::NotesApi* | [**notes_id_put**](docs/NotesApi.md#notes_id_put) | **PUT** /notes/{id} | Update a note
*Pipedrive::NotesApi* | [**notes_post**](docs/NotesApi.md#notes_post) | **POST** /notes | Add a note
*Pipedrive::OrganizationFieldsApi* | [**organization_fields_delete**](docs/OrganizationFieldsApi.md#organization_fields_delete) | **DELETE** /organizationFields | Delete multiple organization fields in bulk
*Pipedrive::OrganizationFieldsApi* | [**organization_fields_get**](docs/OrganizationFieldsApi.md#organization_fields_get) | **GET** /organizationFields | Get all organization fields
*Pipedrive::OrganizationFieldsApi* | [**organization_fields_id_delete**](docs/OrganizationFieldsApi.md#organization_fields_id_delete) | **DELETE** /organizationFields/{id} | Delete an organization field
*Pipedrive::OrganizationFieldsApi* | [**organization_fields_id_get**](docs/OrganizationFieldsApi.md#organization_fields_id_get) | **GET** /organizationFields/{id} | Get one organization field
*Pipedrive::OrganizationFieldsApi* | [**organization_fields_id_put**](docs/OrganizationFieldsApi.md#organization_fields_id_put) | **PUT** /organizationFields/{id} | Update an organization field
*Pipedrive::OrganizationFieldsApi* | [**organization_fields_post**](docs/OrganizationFieldsApi.md#organization_fields_post) | **POST** /organizationFields | Add a new organization field
*Pipedrive::OrganizationRelationshipsApi* | [**organization_relationships_get**](docs/OrganizationRelationshipsApi.md#organization_relationships_get) | **GET** /organizationRelationships | Get all relationships for organization
*Pipedrive::OrganizationRelationshipsApi* | [**organization_relationships_id_delete**](docs/OrganizationRelationshipsApi.md#organization_relationships_id_delete) | **DELETE** /organizationRelationships/{id} | Delete an organization relationship
*Pipedrive::OrganizationRelationshipsApi* | [**organization_relationships_id_get**](docs/OrganizationRelationshipsApi.md#organization_relationships_id_get) | **GET** /organizationRelationships/{id} | Get one organization relationship
*Pipedrive::OrganizationRelationshipsApi* | [**organization_relationships_id_put**](docs/OrganizationRelationshipsApi.md#organization_relationships_id_put) | **PUT** /organizationRelationships/{id} | Update an organization relationship
*Pipedrive::OrganizationRelationshipsApi* | [**organization_relationships_post**](docs/OrganizationRelationshipsApi.md#organization_relationships_post) | **POST** /organizationRelationships | Create an organization relationship
*Pipedrive::OrganizationsApi* | [**organizations_delete**](docs/OrganizationsApi.md#organizations_delete) | **DELETE** /organizations | Delete multiple organizations in bulk
*Pipedrive::OrganizationsApi* | [**organizations_find_get**](docs/OrganizationsApi.md#organizations_find_get) | **GET** /organizations/find | Find organizations by name
*Pipedrive::OrganizationsApi* | [**organizations_get**](docs/OrganizationsApi.md#organizations_get) | **GET** /organizations | Get all organizations
*Pipedrive::OrganizationsApi* | [**organizations_id_activities_get**](docs/OrganizationsApi.md#organizations_id_activities_get) | **GET** /organizations/{id}/activities | List activities associated with an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_deals_get**](docs/OrganizationsApi.md#organizations_id_deals_get) | **GET** /organizations/{id}/deals | List deals associated with an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_delete**](docs/OrganizationsApi.md#organizations_id_delete) | **DELETE** /organizations/{id} | Delete an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_files_get**](docs/OrganizationsApi.md#organizations_id_files_get) | **GET** /organizations/{id}/files | List files attached to an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_flow_get**](docs/OrganizationsApi.md#organizations_id_flow_get) | **GET** /organizations/{id}/flow | List updates about an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_followers_follower_id_delete**](docs/OrganizationsApi.md#organizations_id_followers_follower_id_delete) | **DELETE** /organizations/{id}/followers/{follower_id} | Delete a follower from an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_followers_get**](docs/OrganizationsApi.md#organizations_id_followers_get) | **GET** /organizations/{id}/followers | List followers of an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_followers_post**](docs/OrganizationsApi.md#organizations_id_followers_post) | **POST** /organizations/{id}/followers | Add a follower to an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_get**](docs/OrganizationsApi.md#organizations_id_get) | **GET** /organizations/{id} | Get details of an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_mail_messages_get**](docs/OrganizationsApi.md#organizations_id_mail_messages_get) | **GET** /organizations/{id}/mailMessages | List mail messages associated with an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_merge_put**](docs/OrganizationsApi.md#organizations_id_merge_put) | **PUT** /organizations/{id}/merge | Merge two organizations
*Pipedrive::OrganizationsApi* | [**organizations_id_permitted_users_get**](docs/OrganizationsApi.md#organizations_id_permitted_users_get) | **GET** /organizations/{id}/permittedUsers | List permitted users
*Pipedrive::OrganizationsApi* | [**organizations_id_persons_get**](docs/OrganizationsApi.md#organizations_id_persons_get) | **GET** /organizations/{id}/persons | List persons of an organization
*Pipedrive::OrganizationsApi* | [**organizations_id_put**](docs/OrganizationsApi.md#organizations_id_put) | **PUT** /organizations/{id} | Update an organization
*Pipedrive::OrganizationsApi* | [**organizations_post**](docs/OrganizationsApi.md#organizations_post) | **POST** /organizations | Add an organization
*Pipedrive::OrganizationsApi* | [**organizations_search_get**](docs/OrganizationsApi.md#organizations_search_get) | **GET** /organizations/search | Search organizations
*Pipedrive::PermissionSetsApi* | [**permission_sets_get**](docs/PermissionSetsApi.md#permission_sets_get) | **GET** /permissionSets | Get all Permission Sets
*Pipedrive::PermissionSetsApi* | [**permission_sets_id_assignments_get**](docs/PermissionSetsApi.md#permission_sets_id_assignments_get) | **GET** /permissionSets/{id}/assignments | List Permission Set assignments
*Pipedrive::PermissionSetsApi* | [**permission_sets_id_get**](docs/PermissionSetsApi.md#permission_sets_id_get) | **GET** /permissionSets/{id} | Get one Permission Set
*Pipedrive::PersonFieldsApi* | [**person_fields_delete**](docs/PersonFieldsApi.md#person_fields_delete) | **DELETE** /personFields | Delete multiple person fields in bulk
*Pipedrive::PersonFieldsApi* | [**person_fields_get**](docs/PersonFieldsApi.md#person_fields_get) | **GET** /personFields | Get all person fields
*Pipedrive::PersonFieldsApi* | [**person_fields_id_delete**](docs/PersonFieldsApi.md#person_fields_id_delete) | **DELETE** /personFields/{id} | Delete a person field
*Pipedrive::PersonFieldsApi* | [**person_fields_id_get**](docs/PersonFieldsApi.md#person_fields_id_get) | **GET** /personFields/{id} | Get one person field
*Pipedrive::PersonFieldsApi* | [**person_fields_id_put**](docs/PersonFieldsApi.md#person_fields_id_put) | **PUT** /personFields/{id} | Update a person field
*Pipedrive::PersonFieldsApi* | [**person_fields_post**](docs/PersonFieldsApi.md#person_fields_post) | **POST** /personFields | Add a new person field
*Pipedrive::PersonsApi* | [**persons_delete**](docs/PersonsApi.md#persons_delete) | **DELETE** /persons | Delete multiple persons in bulk
*Pipedrive::PersonsApi* | [**persons_find_get**](docs/PersonsApi.md#persons_find_get) | **GET** /persons/find | Find persons by name
*Pipedrive::PersonsApi* | [**persons_get**](docs/PersonsApi.md#persons_get) | **GET** /persons | Get all persons
*Pipedrive::PersonsApi* | [**persons_id_activities_get**](docs/PersonsApi.md#persons_id_activities_get) | **GET** /persons/{id}/activities | List activities associated with a person
*Pipedrive::PersonsApi* | [**persons_id_deals_get**](docs/PersonsApi.md#persons_id_deals_get) | **GET** /persons/{id}/deals | List deals associated with a person
*Pipedrive::PersonsApi* | [**persons_id_delete**](docs/PersonsApi.md#persons_id_delete) | **DELETE** /persons/{id} | Delete a person
*Pipedrive::PersonsApi* | [**persons_id_files_get**](docs/PersonsApi.md#persons_id_files_get) | **GET** /persons/{id}/files | List files attached to a person
*Pipedrive::PersonsApi* | [**persons_id_flow_get**](docs/PersonsApi.md#persons_id_flow_get) | **GET** /persons/{id}/flow | List updates about a person
*Pipedrive::PersonsApi* | [**persons_id_followers_follower_id_delete**](docs/PersonsApi.md#persons_id_followers_follower_id_delete) | **DELETE** /persons/{id}/followers/{follower_id} | Deletes a follower from a person.
*Pipedrive::PersonsApi* | [**persons_id_followers_get**](docs/PersonsApi.md#persons_id_followers_get) | **GET** /persons/{id}/followers | List followers of a person
*Pipedrive::PersonsApi* | [**persons_id_followers_post**](docs/PersonsApi.md#persons_id_followers_post) | **POST** /persons/{id}/followers | Add a follower to a person
*Pipedrive::PersonsApi* | [**persons_id_get**](docs/PersonsApi.md#persons_id_get) | **GET** /persons/{id} | Get details of a person
*Pipedrive::PersonsApi* | [**persons_id_mail_messages_get**](docs/PersonsApi.md#persons_id_mail_messages_get) | **GET** /persons/{id}/mailMessages | List mail messages associated with a person
*Pipedrive::PersonsApi* | [**persons_id_merge_put**](docs/PersonsApi.md#persons_id_merge_put) | **PUT** /persons/{id}/merge | Merge two persons
*Pipedrive::PersonsApi* | [**persons_id_permitted_users_get**](docs/PersonsApi.md#persons_id_permitted_users_get) | **GET** /persons/{id}/permittedUsers | List permitted users
*Pipedrive::PersonsApi* | [**persons_id_picture_delete**](docs/PersonsApi.md#persons_id_picture_delete) | **DELETE** /persons/{id}/picture | Delete person picture
*Pipedrive::PersonsApi* | [**persons_id_picture_post**](docs/PersonsApi.md#persons_id_picture_post) | **POST** /persons/{id}/picture | Add person picture
*Pipedrive::PersonsApi* | [**persons_id_products_get**](docs/PersonsApi.md#persons_id_products_get) | **GET** /persons/{id}/products | List products associated with a person
*Pipedrive::PersonsApi* | [**persons_id_put**](docs/PersonsApi.md#persons_id_put) | **PUT** /persons/{id} | Update a person
*Pipedrive::PersonsApi* | [**persons_post**](docs/PersonsApi.md#persons_post) | **POST** /persons | Add a person
*Pipedrive::PersonsApi* | [**persons_search_get**](docs/PersonsApi.md#persons_search_get) | **GET** /persons/search | Search persons
*Pipedrive::PipelinesApi* | [**pipelines_get**](docs/PipelinesApi.md#pipelines_get) | **GET** /pipelines | Get all pipelines
*Pipedrive::PipelinesApi* | [**pipelines_id_conversion_statistics_get**](docs/PipelinesApi.md#pipelines_id_conversion_statistics_get) | **GET** /pipelines/{id}/conversion_statistics | Get deals conversion rates in pipeline
*Pipedrive::PipelinesApi* | [**pipelines_id_deals_get**](docs/PipelinesApi.md#pipelines_id_deals_get) | **GET** /pipelines/{id}/deals | Get deals in a pipeline
*Pipedrive::PipelinesApi* | [**pipelines_id_delete**](docs/PipelinesApi.md#pipelines_id_delete) | **DELETE** /pipelines/{id} | Delete a pipeline
*Pipedrive::PipelinesApi* | [**pipelines_id_get**](docs/PipelinesApi.md#pipelines_id_get) | **GET** /pipelines/{id} | Get one pipeline
*Pipedrive::PipelinesApi* | [**pipelines_id_movement_statistics_get**](docs/PipelinesApi.md#pipelines_id_movement_statistics_get) | **GET** /pipelines/{id}/movement_statistics | Get deals movements in pipeline
*Pipedrive::PipelinesApi* | [**pipelines_id_put**](docs/PipelinesApi.md#pipelines_id_put) | **PUT** /pipelines/{id} | Edit a pipeline
*Pipedrive::PipelinesApi* | [**pipelines_post**](docs/PipelinesApi.md#pipelines_post) | **POST** /pipelines | Add a new pipeline
*Pipedrive::ProductFieldsApi* | [**product_fields_delete**](docs/ProductFieldsApi.md#product_fields_delete) | **DELETE** /productFields | Delete multiple product fields in bulk
*Pipedrive::ProductFieldsApi* | [**product_fields_get**](docs/ProductFieldsApi.md#product_fields_get) | **GET** /productFields | Get all product fields
*Pipedrive::ProductFieldsApi* | [**product_fields_id_delete**](docs/ProductFieldsApi.md#product_fields_id_delete) | **DELETE** /productFields/{id} | Delete a product field
*Pipedrive::ProductFieldsApi* | [**product_fields_id_get**](docs/ProductFieldsApi.md#product_fields_id_get) | **GET** /productFields/{id} | Get one product field
*Pipedrive::ProductFieldsApi* | [**product_fields_id_put**](docs/ProductFieldsApi.md#product_fields_id_put) | **PUT** /productFields/{id} | Update a product field
*Pipedrive::ProductFieldsApi* | [**product_fields_post**](docs/ProductFieldsApi.md#product_fields_post) | **POST** /productFields | Add a new product field
*Pipedrive::ProductsApi* | [**products_find_get**](docs/ProductsApi.md#products_find_get) | **GET** /products/find | Find products by name
*Pipedrive::ProductsApi* | [**products_get**](docs/ProductsApi.md#products_get) | **GET** /products | Get all products
*Pipedrive::ProductsApi* | [**products_id_deals_get**](docs/ProductsApi.md#products_id_deals_get) | **GET** /products/{id}/deals | Get deals where a product is attached to
*Pipedrive::ProductsApi* | [**products_id_delete**](docs/ProductsApi.md#products_id_delete) | **DELETE** /products/{id} | Delete a product
*Pipedrive::ProductsApi* | [**products_id_files_get**](docs/ProductsApi.md#products_id_files_get) | **GET** /products/{id}/files | List files attached to a product
*Pipedrive::ProductsApi* | [**products_id_followers_follower_id_delete**](docs/ProductsApi.md#products_id_followers_follower_id_delete) | **DELETE** /products/{id}/followers/{follower_id} | Delete a follower from a product
*Pipedrive::ProductsApi* | [**products_id_followers_get**](docs/ProductsApi.md#products_id_followers_get) | **GET** /products/{id}/followers | List followers of a product
*Pipedrive::ProductsApi* | [**products_id_followers_post**](docs/ProductsApi.md#products_id_followers_post) | **POST** /products/{id}/followers | Add a follower to a product
*Pipedrive::ProductsApi* | [**products_id_get**](docs/ProductsApi.md#products_id_get) | **GET** /products/{id} | Get one product
*Pipedrive::ProductsApi* | [**products_id_permitted_users_get**](docs/ProductsApi.md#products_id_permitted_users_get) | **GET** /products/{id}/permittedUsers | List permitted users
*Pipedrive::ProductsApi* | [**products_id_put**](docs/ProductsApi.md#products_id_put) | **PUT** /products/{id} | Update a product
*Pipedrive::ProductsApi* | [**products_post**](docs/ProductsApi.md#products_post) | **POST** /products | Add a product
*Pipedrive::ProductsApi* | [**products_search_get**](docs/ProductsApi.md#products_search_get) | **GET** /products/search | Search products
*Pipedrive::RecentsApi* | [**recents_get**](docs/RecentsApi.md#recents_get) | **GET** /recents | Get recents
*Pipedrive::RolesApi* | [**roles_get**](docs/RolesApi.md#roles_get) | **GET** /roles | Get all roles
*Pipedrive::RolesApi* | [**roles_id_assignments_delete**](docs/RolesApi.md#roles_id_assignments_delete) | **DELETE** /roles/{id}/assignments | Delete a role assignment
*Pipedrive::RolesApi* | [**roles_id_assignments_get**](docs/RolesApi.md#roles_id_assignments_get) | **GET** /roles/{id}/assignments | List role assignments
*Pipedrive::RolesApi* | [**roles_id_assignments_post**](docs/RolesApi.md#roles_id_assignments_post) | **POST** /roles/{id}/assignments | Add role assignment
*Pipedrive::RolesApi* | [**roles_id_delete**](docs/RolesApi.md#roles_id_delete) | **DELETE** /roles/{id} | Delete a role
*Pipedrive::RolesApi* | [**roles_id_get**](docs/RolesApi.md#roles_id_get) | **GET** /roles/{id} | Get one role
*Pipedrive::RolesApi* | [**roles_id_put**](docs/RolesApi.md#roles_id_put) | **PUT** /roles/{id} | Update role details
*Pipedrive::RolesApi* | [**roles_id_roles_get**](docs/RolesApi.md#roles_id_roles_get) | **GET** /roles/{id}/roles | List role sub-roles
*Pipedrive::RolesApi* | [**roles_id_settings_get**](docs/RolesApi.md#roles_id_settings_get) | **GET** /roles/{id}/settings | List role settings
*Pipedrive::RolesApi* | [**roles_id_settings_post**](docs/RolesApi.md#roles_id_settings_post) | **POST** /roles/{id}/settings | Add or update role setting
*Pipedrive::RolesApi* | [**roles_post**](docs/RolesApi.md#roles_post) | **POST** /roles | Add a role
*Pipedrive::SearchResultsApi* | [**search_results_field_get**](docs/SearchResultsApi.md#search_results_field_get) | **GET** /searchResults/field | Perform a search using a specific field value
*Pipedrive::SearchResultsApi* | [**search_results_get**](docs/SearchResultsApi.md#search_results_get) | **GET** /searchResults | Perform a search
*Pipedrive::StagesApi* | [**stages_delete**](docs/StagesApi.md#stages_delete) | **DELETE** /stages | Delete multiple stages in bulk
*Pipedrive::StagesApi* | [**stages_get**](docs/StagesApi.md#stages_get) | **GET** /stages | Get all stages
*Pipedrive::StagesApi* | [**stages_id_deals_get**](docs/StagesApi.md#stages_id_deals_get) | **GET** /stages/{id}/deals | Get deals in a stage
*Pipedrive::StagesApi* | [**stages_id_delete**](docs/StagesApi.md#stages_id_delete) | **DELETE** /stages/{id} | Delete a stage
*Pipedrive::StagesApi* | [**stages_id_get**](docs/StagesApi.md#stages_id_get) | **GET** /stages/{id} | Get one stage
*Pipedrive::StagesApi* | [**stages_id_put**](docs/StagesApi.md#stages_id_put) | **PUT** /stages/{id} | Update stage details
*Pipedrive::StagesApi* | [**stages_post**](docs/StagesApi.md#stages_post) | **POST** /stages | Add a new stage
*Pipedrive::TeamsApi* | [**teams_get**](docs/TeamsApi.md#teams_get) | **GET** /teams | Get all teams
*Pipedrive::TeamsApi* | [**teams_id_get**](docs/TeamsApi.md#teams_id_get) | **GET** /teams/{id} | Get a single team
*Pipedrive::TeamsApi* | [**teams_id_put**](docs/TeamsApi.md#teams_id_put) | **PUT** /teams/{id} | Update a team
*Pipedrive::TeamsApi* | [**teams_id_users_delete**](docs/TeamsApi.md#teams_id_users_delete) | **DELETE** /teams/{id}/users | Delete users from a team
*Pipedrive::TeamsApi* | [**teams_id_users_get**](docs/TeamsApi.md#teams_id_users_get) | **GET** /teams/{id}/users | Get all users in a team
*Pipedrive::TeamsApi* | [**teams_id_users_post**](docs/TeamsApi.md#teams_id_users_post) | **POST** /teams/{id}/users | Add users to a team
*Pipedrive::TeamsApi* | [**teams_post**](docs/TeamsApi.md#teams_post) | **POST** /teams | Add a new team
*Pipedrive::TeamsApi* | [**teams_user_id_get**](docs/TeamsApi.md#teams_user_id_get) | **GET** /teams/user/{id} | Get all teams of a user
*Pipedrive::UserConnectionsApi* | [**user_connections_get**](docs/UserConnectionsApi.md#user_connections_get) | **GET** /userConnections | Get all user connections
*Pipedrive::UserSettingsApi* | [**user_settings_get**](docs/UserSettingsApi.md#user_settings_get) | **GET** /userSettings | List settings of an authorized user
*Pipedrive::UsersApi* | [**users_find_get**](docs/UsersApi.md#users_find_get) | **GET** /users/find | Find users by name
*Pipedrive::UsersApi* | [**users_get**](docs/UsersApi.md#users_get) | **GET** /users | Get all users
*Pipedrive::UsersApi* | [**users_id_blacklisted_emails_get**](docs/UsersApi.md#users_id_blacklisted_emails_get) | **GET** /users/{id}/blacklistedEmails | List blacklisted email addresses of a user
*Pipedrive::UsersApi* | [**users_id_blacklisted_emails_post**](docs/UsersApi.md#users_id_blacklisted_emails_post) | **POST** /users/{id}/blacklistedEmails | Add blacklisted email address for a user
*Pipedrive::UsersApi* | [**users_id_followers_get**](docs/UsersApi.md#users_id_followers_get) | **GET** /users/{id}/followers | List followers of a user
*Pipedrive::UsersApi* | [**users_id_get**](docs/UsersApi.md#users_id_get) | **GET** /users/{id} | Get one user
*Pipedrive::UsersApi* | [**users_id_permissions_get**](docs/UsersApi.md#users_id_permissions_get) | **GET** /users/{id}/permissions | List user permissions
*Pipedrive::UsersApi* | [**users_id_put**](docs/UsersApi.md#users_id_put) | **PUT** /users/{id} | Update user details
*Pipedrive::UsersApi* | [**users_id_role_assignments_delete**](docs/UsersApi.md#users_id_role_assignments_delete) | **DELETE** /users/{id}/roleAssignments | Delete a role assignment
*Pipedrive::UsersApi* | [**users_id_role_assignments_get**](docs/UsersApi.md#users_id_role_assignments_get) | **GET** /users/{id}/roleAssignments | List role assignments
*Pipedrive::UsersApi* | [**users_id_role_assignments_post**](docs/UsersApi.md#users_id_role_assignments_post) | **POST** /users/{id}/roleAssignments | Add role assignment
*Pipedrive::UsersApi* | [**users_id_role_settings_get**](docs/UsersApi.md#users_id_role_settings_get) | **GET** /users/{id}/roleSettings | List user role settings
*Pipedrive::UsersApi* | [**users_me_get**](docs/UsersApi.md#users_me_get) | **GET** /users/me | Get current user data
*Pipedrive::UsersApi* | [**users_post**](docs/UsersApi.md#users_post) | **POST** /users | Add a new user
*Pipedrive::WebhooksApi* | [**webhooks_get**](docs/WebhooksApi.md#webhooks_get) | **GET** /webhooks | Get all webhooks
*Pipedrive::WebhooksApi* | [**webhooks_id_delete**](docs/WebhooksApi.md#webhooks_id_delete) | **DELETE** /webhooks/{id} | Delete existing webhook
*Pipedrive::WebhooksApi* | [**webhooks_post**](docs/WebhooksApi.md#webhooks_post) | **POST** /webhooks | Create a new webhook


## Documentation for Models

 - [Pipedrive::Activity](docs/Activity.md)
 - [Pipedrive::AddFile](docs/AddFile.md)
 - [Pipedrive::AddNewPipeline](docs/AddNewPipeline.md)
 - [Pipedrive::AddNewPipelineAllOf](docs/AddNewPipelineAllOf.md)
 - [Pipedrive::AddedDealFollower](docs/AddedDealFollower.md)
 - [Pipedrive::AddedDealFollowerData](docs/AddedDealFollowerData.md)
 - [Pipedrive::AdditionalData](docs/AdditionalData.md)
 - [Pipedrive::AdditionalDataWithPaginationDetails](docs/AdditionalDataWithPaginationDetails.md)
 - [Pipedrive::BaseCurrency](docs/BaseCurrency.md)
 - [Pipedrive::BaseDeal](docs/BaseDeal.md)
 - [Pipedrive::BaseMailThread](docs/BaseMailThread.md)
 - [Pipedrive::BaseMailThreadAllOf](docs/BaseMailThreadAllOf.md)
 - [Pipedrive::BaseMailThreadAllOfParties](docs/BaseMailThreadAllOfParties.md)
 - [Pipedrive::BaseMailThreadMessages](docs/BaseMailThreadMessages.md)
 - [Pipedrive::BaseMailThreadMessagesAllOf](docs/BaseMailThreadMessagesAllOf.md)
 - [Pipedrive::BaseNote](docs/BaseNote.md)
 - [Pipedrive::BaseNoteDealTitle](docs/BaseNoteDealTitle.md)
 - [Pipedrive::BaseNoteOrganization](docs/BaseNoteOrganization.md)
 - [Pipedrive::BaseNotePerson](docs/BaseNotePerson.md)
 - [Pipedrive::BaseResponse](docs/BaseResponse.md)
 - [Pipedrive::BaseRole](docs/BaseRole.md)
 - [Pipedrive::BaseStage](docs/BaseStage.md)
 - [Pipedrive::BaseTeam](docs/BaseTeam.md)
 - [Pipedrive::BaseTeamAllOf](docs/BaseTeamAllOf.md)
 - [Pipedrive::BaseTeamAllOf1](docs/BaseTeamAllOf1.md)
 - [Pipedrive::BaseUser](docs/BaseUser.md)
 - [Pipedrive::BaseUserMe](docs/BaseUserMe.md)
 - [Pipedrive::BaseUserMeAllOf](docs/BaseUserMeAllOf.md)
 - [Pipedrive::BaseUserMeAllOfLanguage](docs/BaseUserMeAllOfLanguage.md)
 - [Pipedrive::BasicDeal](docs/BasicDeal.md)
 - [Pipedrive::BasicDealProduct](docs/BasicDealProduct.md)
 - [Pipedrive::BasicGoal](docs/BasicGoal.md)
 - [Pipedrive::BasicOrganization](docs/BasicOrganization.md)
 - [Pipedrive::BasicPerson](docs/BasicPerson.md)
 - [Pipedrive::BasicPersonField](docs/BasicPersonField.md)
 - [Pipedrive::BasicProductField](docs/BasicProductField.md)
 - [Pipedrive::CommonMailThread](docs/CommonMailThread.md)
 - [Pipedrive::CreateRemoteFileAndLinkItToItem](docs/CreateRemoteFileAndLinkItToItem.md)
 - [Pipedrive::CreateTeam](docs/CreateTeam.md)
 - [Pipedrive::Currencies](docs/Currencies.md)
 - [Pipedrive::DealNonStrictModeFields](docs/DealNonStrictModeFields.md)
 - [Pipedrive::DealNonStrictModeFieldsCreatorUserId](docs/DealNonStrictModeFieldsCreatorUserId.md)
 - [Pipedrive::DealOrganizationData](docs/DealOrganizationData.md)
 - [Pipedrive::DealPersonData](docs/DealPersonData.md)
 - [Pipedrive::DealPersonDataEmail](docs/DealPersonDataEmail.md)
 - [Pipedrive::DealPersonDataPhone](docs/DealPersonDataPhone.md)
 - [Pipedrive::DealStrictModeFields](docs/DealStrictModeFields.md)
 - [Pipedrive::DealSummary](docs/DealSummary.md)
 - [Pipedrive::DealSummaryPerCurrency](docs/DealSummaryPerCurrency.md)
 - [Pipedrive::DealSummaryPerCurrencyFull](docs/DealSummaryPerCurrencyFull.md)
 - [Pipedrive::DealSummaryPerCurrencyFullCURRENCYID](docs/DealSummaryPerCurrencyFullCURRENCYID.md)
 - [Pipedrive::DealSummaryPerStages](docs/DealSummaryPerStages.md)
 - [Pipedrive::DealSummaryPerStagesSTAGEID](docs/DealSummaryPerStagesSTAGEID.md)
 - [Pipedrive::DealSummaryPerStagesSTAGEIDCURRENCYID](docs/DealSummaryPerStagesSTAGEIDCURRENCYID.md)
 - [Pipedrive::DealUserData](docs/DealUserData.md)
 - [Pipedrive::DeleteDeal](docs/DeleteDeal.md)
 - [Pipedrive::DeleteDealData](docs/DeleteDealData.md)
 - [Pipedrive::DeleteDealFollower](docs/DeleteDealFollower.md)
 - [Pipedrive::DeleteDealFollowerData](docs/DeleteDealFollowerData.md)
 - [Pipedrive::DeleteDealParticipant](docs/DeleteDealParticipant.md)
 - [Pipedrive::DeleteDealParticipantData](docs/DeleteDealParticipantData.md)
 - [Pipedrive::DeleteDealProduct](docs/DeleteDealProduct.md)
 - [Pipedrive::DeleteDealProductData](docs/DeleteDealProductData.md)
 - [Pipedrive::DeleteFile](docs/DeleteFile.md)
 - [Pipedrive::DeleteFileData](docs/DeleteFileData.md)
 - [Pipedrive::DeleteMultipleDeals](docs/DeleteMultipleDeals.md)
 - [Pipedrive::DeleteMultipleDealsAllOf](docs/DeleteMultipleDealsAllOf.md)
 - [Pipedrive::DeleteMultipleDealsAllOfData](docs/DeleteMultipleDealsAllOfData.md)
 - [Pipedrive::DeleteMultipleProductFieldsResponse](docs/DeleteMultipleProductFieldsResponse.md)
 - [Pipedrive::DeleteMultipleProductFieldsResponseData](docs/DeleteMultipleProductFieldsResponseData.md)
 - [Pipedrive::DeleteNote](docs/DeleteNote.md)
 - [Pipedrive::DeleteProductFieldResponse](docs/DeleteProductFieldResponse.md)
 - [Pipedrive::DeleteProductFieldResponseData](docs/DeleteProductFieldResponseData.md)
 - [Pipedrive::DeleteProductFollowerResponse](docs/DeleteProductFollowerResponse.md)
 - [Pipedrive::DeleteProductFollowerResponseData](docs/DeleteProductFollowerResponseData.md)
 - [Pipedrive::DeleteRole](docs/DeleteRole.md)
 - [Pipedrive::DeleteRoleAllOf](docs/DeleteRoleAllOf.md)
 - [Pipedrive::DeleteRoleAllOfData](docs/DeleteRoleAllOfData.md)
 - [Pipedrive::DeleteRoleAssignment](docs/DeleteRoleAssignment.md)
 - [Pipedrive::DeleteRoleAssignmentAllOf](docs/DeleteRoleAssignmentAllOf.md)
 - [Pipedrive::DeleteRoleAssignmentAllOfData](docs/DeleteRoleAssignmentAllOfData.md)
 - [Pipedrive::EditPipeline](docs/EditPipeline.md)
 - [Pipedrive::EditPipelineAllOf](docs/EditPipelineAllOf.md)
 - [Pipedrive::FailResponse](docs/FailResponse.md)
 - [Pipedrive::FieldType](docs/FieldType.md)
 - [Pipedrive::FileData](docs/FileData.md)
 - [Pipedrive::FilterType](docs/FilterType.md)
 - [Pipedrive::FindProductsByNameResponse](docs/FindProductsByNameResponse.md)
 - [Pipedrive::FindProductsByNameResponseData](docs/FindProductsByNameResponseData.md)
 - [Pipedrive::FullRole](docs/FullRole.md)
 - [Pipedrive::FullRoleAllOf](docs/FullRoleAllOf.md)
 - [Pipedrive::GetAddProductAttachementDetails](docs/GetAddProductAttachementDetails.md)
 - [Pipedrive::GetAddUpdateStage](docs/GetAddUpdateStage.md)
 - [Pipedrive::GetAddedDeal](docs/GetAddedDeal.md)
 - [Pipedrive::GetAddedDealAdditionalData](docs/GetAddedDealAdditionalData.md)
 - [Pipedrive::GetAddedDealRelatedObjects](docs/GetAddedDealRelatedObjects.md)
 - [Pipedrive::GetAllFiles](docs/GetAllFiles.md)
 - [Pipedrive::GetAllPipelines](docs/GetAllPipelines.md)
 - [Pipedrive::GetAllPipelinesAllOf](docs/GetAllPipelinesAllOf.md)
 - [Pipedrive::GetAllProductFieldsResponse](docs/GetAllProductFieldsResponse.md)
 - [Pipedrive::GetDeal](docs/GetDeal.md)
 - [Pipedrive::GetDealAdditionalData](docs/GetDealAdditionalData.md)
 - [Pipedrive::GetDeals](docs/GetDeals.md)
 - [Pipedrive::GetDealsByName](docs/GetDealsByName.md)
 - [Pipedrive::GetDealsByNameAdditionalData](docs/GetDealsByNameAdditionalData.md)
 - [Pipedrive::GetDealsByNameData](docs/GetDealsByNameData.md)
 - [Pipedrive::GetDealsConversionRatesInPipeline](docs/GetDealsConversionRatesInPipeline.md)
 - [Pipedrive::GetDealsConversionRatesInPipelineAllOf](docs/GetDealsConversionRatesInPipelineAllOf.md)
 - [Pipedrive::GetDealsConversionRatesInPipelineAllOfData](docs/GetDealsConversionRatesInPipelineAllOfData.md)
 - [Pipedrive::GetDealsConversionRatesInPipelineAllOfDataStageConversions](docs/GetDealsConversionRatesInPipelineAllOfDataStageConversions.md)
 - [Pipedrive::GetDealsMovementsInPipeline](docs/GetDealsMovementsInPipeline.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOf](docs/GetDealsMovementsInPipelineAllOf.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOfData](docs/GetDealsMovementsInPipelineAllOfData.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOfDataAverageAgeInDays](docs/GetDealsMovementsInPipelineAllOfDataAverageAgeInDays.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOfDataAverageAgeInDaysByStages](docs/GetDealsMovementsInPipelineAllOfDataAverageAgeInDaysByStages.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOfDataMovementsBetweenStages](docs/GetDealsMovementsInPipelineAllOfDataMovementsBetweenStages.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOfDataNewDeals](docs/GetDealsMovementsInPipelineAllOfDataNewDeals.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOfDataNewDealsFormattedValues](docs/GetDealsMovementsInPipelineAllOfDataNewDealsFormattedValues.md)
 - [Pipedrive::GetDealsMovementsInPipelineAllOfDataNewDealsValues](docs/GetDealsMovementsInPipelineAllOfDataNewDealsValues.md)
 - [Pipedrive::GetDealsSummary](docs/GetDealsSummary.md)
 - [Pipedrive::GetDealsSummaryData](docs/GetDealsSummaryData.md)
 - [Pipedrive::GetDealsSummaryDataValuesTotal](docs/GetDealsSummaryDataValuesTotal.md)
 - [Pipedrive::GetDealsSummaryDataWeightedValuesTotal](docs/GetDealsSummaryDataWeightedValuesTotal.md)
 - [Pipedrive::GetDealsTimeline](docs/GetDealsTimeline.md)
 - [Pipedrive::GetDealsTimelineData](docs/GetDealsTimelineData.md)
 - [Pipedrive::GetDealsTimelineDataTotals](docs/GetDealsTimelineDataTotals.md)
 - [Pipedrive::GetDuplicatedDeal](docs/GetDuplicatedDeal.md)
 - [Pipedrive::GetMergedDeal](docs/GetMergedDeal.md)
 - [Pipedrive::GetNotes](docs/GetNotes.md)
 - [Pipedrive::GetOneFile](docs/GetOneFile.md)
 - [Pipedrive::GetOnePipeline](docs/GetOnePipeline.md)
 - [Pipedrive::GetOnePipelineAllOf](docs/GetOnePipelineAllOf.md)
 - [Pipedrive::GetOneStage](docs/GetOneStage.md)
 - [Pipedrive::GetProductAttachementDetails](docs/GetProductAttachementDetails.md)
 - [Pipedrive::GetProductFieldResponse](docs/GetProductFieldResponse.md)
 - [Pipedrive::GetRole](docs/GetRole.md)
 - [Pipedrive::GetRoleAllOf](docs/GetRoleAllOf.md)
 - [Pipedrive::GetRoleAllOfAdditionalData](docs/GetRoleAllOfAdditionalData.md)
 - [Pipedrive::GetRoleAssignments](docs/GetRoleAssignments.md)
 - [Pipedrive::GetRoleAssignmentsAllOf](docs/GetRoleAssignmentsAllOf.md)
 - [Pipedrive::GetRoleSettings](docs/GetRoleSettings.md)
 - [Pipedrive::GetRoleSettingsAllOf](docs/GetRoleSettingsAllOf.md)
 - [Pipedrive::GetRoleSubroles](docs/GetRoleSubroles.md)
 - [Pipedrive::GetRoleSubrolesAllOf](docs/GetRoleSubrolesAllOf.md)
 - [Pipedrive::GetRoles](docs/GetRoles.md)
 - [Pipedrive::GetRolesAllOf](docs/GetRolesAllOf.md)
 - [Pipedrive::GetStageDeals](docs/GetStageDeals.md)
 - [Pipedrive::GetStages](docs/GetStages.md)
 - [Pipedrive::GlobalMessageBaseResponse](docs/GlobalMessageBaseResponse.md)
 - [Pipedrive::GlobalMessageData](docs/GlobalMessageData.md)
 - [Pipedrive::GlobalMessageDelete](docs/GlobalMessageDelete.md)
 - [Pipedrive::GlobalMessageDeleteAllOf](docs/GlobalMessageDeleteAllOf.md)
 - [Pipedrive::GlobalMessageGet](docs/GlobalMessageGet.md)
 - [Pipedrive::GlobalMessageGetAllOf](docs/GlobalMessageGetAllOf.md)
 - [Pipedrive::GlobalMessageUserData](docs/GlobalMessageUserData.md)
 - [Pipedrive::IconKey](docs/IconKey.md)
 - [Pipedrive::InlineObject](docs/InlineObject.md)
 - [Pipedrive::InlineObject1](docs/InlineObject1.md)
 - [Pipedrive::InlineObject10](docs/InlineObject10.md)
 - [Pipedrive::InlineObject11](docs/InlineObject11.md)
 - [Pipedrive::InlineObject12](docs/InlineObject12.md)
 - [Pipedrive::InlineObject13](docs/InlineObject13.md)
 - [Pipedrive::InlineObject14](docs/InlineObject14.md)
 - [Pipedrive::InlineObject15](docs/InlineObject15.md)
 - [Pipedrive::InlineObject16](docs/InlineObject16.md)
 - [Pipedrive::InlineObject17](docs/InlineObject17.md)
 - [Pipedrive::InlineObject18](docs/InlineObject18.md)
 - [Pipedrive::InlineObject19](docs/InlineObject19.md)
 - [Pipedrive::InlineObject2](docs/InlineObject2.md)
 - [Pipedrive::InlineObject20](docs/InlineObject20.md)
 - [Pipedrive::InlineObject21](docs/InlineObject21.md)
 - [Pipedrive::InlineObject22](docs/InlineObject22.md)
 - [Pipedrive::InlineObject23](docs/InlineObject23.md)
 - [Pipedrive::InlineObject24](docs/InlineObject24.md)
 - [Pipedrive::InlineObject25](docs/InlineObject25.md)
 - [Pipedrive::InlineObject26](docs/InlineObject26.md)
 - [Pipedrive::InlineObject27](docs/InlineObject27.md)
 - [Pipedrive::InlineObject28](docs/InlineObject28.md)
 - [Pipedrive::InlineObject29](docs/InlineObject29.md)
 - [Pipedrive::InlineObject3](docs/InlineObject3.md)
 - [Pipedrive::InlineObject30](docs/InlineObject30.md)
 - [Pipedrive::InlineObject31](docs/InlineObject31.md)
 - [Pipedrive::InlineObject32](docs/InlineObject32.md)
 - [Pipedrive::InlineObject33](docs/InlineObject33.md)
 - [Pipedrive::InlineObject4](docs/InlineObject4.md)
 - [Pipedrive::InlineObject5](docs/InlineObject5.md)
 - [Pipedrive::InlineObject6](docs/InlineObject6.md)
 - [Pipedrive::InlineObject7](docs/InlineObject7.md)
 - [Pipedrive::InlineObject8](docs/InlineObject8.md)
 - [Pipedrive::InlineObject9](docs/InlineObject9.md)
 - [Pipedrive::InlineResponse200](docs/InlineResponse200.md)
 - [Pipedrive::InlineResponse2001](docs/InlineResponse2001.md)
 - [Pipedrive::InlineResponse20010](docs/InlineResponse20010.md)
 - [Pipedrive::InlineResponse20010Data](docs/InlineResponse20010Data.md)
 - [Pipedrive::InlineResponse20011](docs/InlineResponse20011.md)
 - [Pipedrive::InlineResponse20011Data](docs/InlineResponse20011Data.md)
 - [Pipedrive::InlineResponse2002](docs/InlineResponse2002.md)
 - [Pipedrive::InlineResponse2003](docs/InlineResponse2003.md)
 - [Pipedrive::InlineResponse2004](docs/InlineResponse2004.md)
 - [Pipedrive::InlineResponse2005](docs/InlineResponse2005.md)
 - [Pipedrive::InlineResponse2006](docs/InlineResponse2006.md)
 - [Pipedrive::InlineResponse2007](docs/InlineResponse2007.md)
 - [Pipedrive::InlineResponse2007Data](docs/InlineResponse2007Data.md)
 - [Pipedrive::InlineResponse2008](docs/InlineResponse2008.md)
 - [Pipedrive::InlineResponse2008Data](docs/InlineResponse2008Data.md)
 - [Pipedrive::InlineResponse2009](docs/InlineResponse2009.md)
 - [Pipedrive::InlineResponse2009Data](docs/InlineResponse2009Data.md)
 - [Pipedrive::InlineResponse200AdditionalData](docs/InlineResponse200AdditionalData.md)
 - [Pipedrive::InlineResponse201](docs/InlineResponse201.md)
 - [Pipedrive::InlineResponse201Data](docs/InlineResponse201Data.md)
 - [Pipedrive::InlineResponse400](docs/InlineResponse400.md)
 - [Pipedrive::InlineResponse403](docs/InlineResponse403.md)
 - [Pipedrive::InlineResponse404](docs/InlineResponse404.md)
 - [Pipedrive::InlineResponse4041](docs/InlineResponse4041.md)
 - [Pipedrive::InlineResponse409](docs/InlineResponse409.md)
 - [Pipedrive::InlineResponse410](docs/InlineResponse410.md)
 - [Pipedrive::InlineResponse500](docs/InlineResponse500.md)
 - [Pipedrive::LeadsValue](docs/LeadsValue.md)
 - [Pipedrive::LinkRemoteFileToItem](docs/LinkRemoteFileToItem.md)
 - [Pipedrive::MailMessage](docs/MailMessage.md)
 - [Pipedrive::MailMessageAllOf](docs/MailMessageAllOf.md)
 - [Pipedrive::MailMessageData](docs/MailMessageData.md)
 - [Pipedrive::MailParticipant](docs/MailParticipant.md)
 - [Pipedrive::MailServiceBaseResponse](docs/MailServiceBaseResponse.md)
 - [Pipedrive::MailThread](docs/MailThread.md)
 - [Pipedrive::MailThreadAllOf](docs/MailThreadAllOf.md)
 - [Pipedrive::MailThreadDelete](docs/MailThreadDelete.md)
 - [Pipedrive::MailThreadDeleteAllOf](docs/MailThreadDeleteAllOf.md)
 - [Pipedrive::MailThreadMessages](docs/MailThreadMessages.md)
 - [Pipedrive::MailThreadMessagesAllOf](docs/MailThreadMessagesAllOf.md)
 - [Pipedrive::MailThreadOne](docs/MailThreadOne.md)
 - [Pipedrive::MailThreadOneAllOf](docs/MailThreadOneAllOf.md)
 - [Pipedrive::MailThreadParticipant](docs/MailThreadParticipant.md)
 - [Pipedrive::MailThreadPut](docs/MailThreadPut.md)
 - [Pipedrive::NewDeal](docs/NewDeal.md)
 - [Pipedrive::NewDealAllOf](docs/NewDealAllOf.md)
 - [Pipedrive::NewDealProduct](docs/NewDealProduct.md)
 - [Pipedrive::NewDealProductAllOf](docs/NewDealProductAllOf.md)
 - [Pipedrive::NewFollowerResponse](docs/NewFollowerResponse.md)
 - [Pipedrive::NewFollowerResponseData](docs/NewFollowerResponseData.md)
 - [Pipedrive::NewGoal](docs/NewGoal.md)
 - [Pipedrive::NewOrganization](docs/NewOrganization.md)
 - [Pipedrive::NewOrganizationAllOf](docs/NewOrganizationAllOf.md)
 - [Pipedrive::NewOrganizationField](docs/NewOrganizationField.md)
 - [Pipedrive::NewPerson](docs/NewPerson.md)
 - [Pipedrive::NewPersonAllOf](docs/NewPersonAllOf.md)
 - [Pipedrive::NewPersonField](docs/NewPersonField.md)
 - [Pipedrive::NewProductField](docs/NewProductField.md)
 - [Pipedrive::NewProductFieldAllOf](docs/NewProductFieldAllOf.md)
 - [Pipedrive::Note](docs/Note.md)
 - [Pipedrive::NoteCreatorUser](docs/NoteCreatorUser.md)
 - [Pipedrive::NumberBoolean](docs/NumberBoolean.md)
 - [Pipedrive::NumberBooleanDefault0](docs/NumberBooleanDefault0.md)
 - [Pipedrive::NumberBooleanDefault1](docs/NumberBooleanDefault1.md)
 - [Pipedrive::OrganizationRelationship](docs/OrganizationRelationship.md)
 - [Pipedrive::PermissionSets](docs/PermissionSets.md)
 - [Pipedrive::PermissionSetsAllOf](docs/PermissionSetsAllOf.md)
 - [Pipedrive::PermissionSetsItem](docs/PermissionSetsItem.md)
 - [Pipedrive::Pipeline](docs/Pipeline.md)
 - [Pipedrive::PostNote](docs/PostNote.md)
 - [Pipedrive::PostRoleAssignment](docs/PostRoleAssignment.md)
 - [Pipedrive::PostRoleAssignmentAllOf](docs/PostRoleAssignmentAllOf.md)
 - [Pipedrive::PostRoleAssignmentAllOfData](docs/PostRoleAssignmentAllOfData.md)
 - [Pipedrive::PostRoleSettings](docs/PostRoleSettings.md)
 - [Pipedrive::PostRoleSettingsAllOf](docs/PostRoleSettingsAllOf.md)
 - [Pipedrive::PostRoleSettingsAllOfData](docs/PostRoleSettingsAllOfData.md)
 - [Pipedrive::PostRoles](docs/PostRoles.md)
 - [Pipedrive::PostRolesAllOf](docs/PostRolesAllOf.md)
 - [Pipedrive::PostRolesAllOfData](docs/PostRolesAllOfData.md)
 - [Pipedrive::Product](docs/Product.md)
 - [Pipedrive::ProductAttachementFields](docs/ProductAttachementFields.md)
 - [Pipedrive::ProductField](docs/ProductField.md)
 - [Pipedrive::ProductFieldAllOf](docs/ProductFieldAllOf.md)
 - [Pipedrive::PutRole](docs/PutRole.md)
 - [Pipedrive::PutRoleAllOf](docs/PutRoleAllOf.md)
 - [Pipedrive::PutRoleAllOfData](docs/PutRoleAllOfData.md)
 - [Pipedrive::RoleAssignment](docs/RoleAssignment.md)
 - [Pipedrive::RoleAssignmentAllOf](docs/RoleAssignmentAllOf.md)
 - [Pipedrive::RoleSettings](docs/RoleSettings.md)
 - [Pipedrive::RolesAdditionalData](docs/RolesAdditionalData.md)
 - [Pipedrive::RolesAdditionalDataPagination](docs/RolesAdditionalDataPagination.md)
 - [Pipedrive::SinglePermissionSetsItem](docs/SinglePermissionSetsItem.md)
 - [Pipedrive::SinglePermissionSetsItemAllOf](docs/SinglePermissionSetsItemAllOf.md)
 - [Pipedrive::Stage](docs/Stage.md)
 - [Pipedrive::SubRole](docs/SubRole.md)
 - [Pipedrive::SubRoleAllOf](docs/SubRoleAllOf.md)
 - [Pipedrive::Teams](docs/Teams.md)
 - [Pipedrive::TeamsAllOf](docs/TeamsAllOf.md)
 - [Pipedrive::Unauthorized](docs/Unauthorized.md)
 - [Pipedrive::UpdateFile](docs/UpdateFile.md)
 - [Pipedrive::UpdateTeam](docs/UpdateTeam.md)
 - [Pipedrive::UpdateTeamAllOf](docs/UpdateTeamAllOf.md)
 - [Pipedrive::User](docs/User.md)
 - [Pipedrive::UserAllOf](docs/UserAllOf.md)
 - [Pipedrive::UserAssignmentToPermissionSet](docs/UserAssignmentToPermissionSet.md)
 - [Pipedrive::UserAssignmentsToPermissionSet](docs/UserAssignmentsToPermissionSet.md)
 - [Pipedrive::UserAssignmentsToPermissionSetAllOf](docs/UserAssignmentsToPermissionSetAllOf.md)
 - [Pipedrive::UserConnections](docs/UserConnections.md)
 - [Pipedrive::UserConnectionsAllOf](docs/UserConnectionsAllOf.md)
 - [Pipedrive::UserConnectionsAllOfData](docs/UserConnectionsAllOfData.md)
 - [Pipedrive::UserIDs](docs/UserIDs.md)
 - [Pipedrive::UserIDsAllOf](docs/UserIDsAllOf.md)
 - [Pipedrive::UserMe](docs/UserMe.md)
 - [Pipedrive::UserMeAllOf](docs/UserMeAllOf.md)
 - [Pipedrive::UserSettings](docs/UserSettings.md)
 - [Pipedrive::UserSettingsAllOf](docs/UserSettingsAllOf.md)
 - [Pipedrive::UserSettingsItem](docs/UserSettingsItem.md)
 - [Pipedrive::Users](docs/Users.md)
 - [Pipedrive::UsersAllOf](docs/UsersAllOf.md)
 - [Pipedrive::VisibleTo](docs/VisibleTo.md)


## Documentation for Authorization


### api_key


- **Type**: API key
- **API key parameter name**: api_token
- **Location**: URL query string

### oauth2


- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://oauth.pipedrive.com/oauth/authorize
- **Scopes**: 
  - deals:read: Read most data about deals and related entities.
  - deals:full: Create, read, update and delete deals, its participants and followers.
  - activities:read: Read activities, its fields and types; all files and filters.
  - activities:full: Create, read, update and delete activities and all files and filters.
  - contacts:read: Read data about persons and organizations, their related fields and followers.
  - contacts:full: Create, read, update and delete persons and organizations and their followers.
  - admin: Allows to do many things that an administrator can do in a Pipedrive company account.
  - recents:read: Read all recent changes occured in an account.
  - search:read: Search across the account for deals, persons, organizations, files and products and see details about the returned results.
  - mail:read: Read mail threads and messages.
  - mail:full: Read, update and delete mail threads. Also grants read access to mail messages.
  - products:read: Read products, its fields, files, followers and products connected to a deal.
  - products:full: Create, read, update and delete products and its fields; add products to deals
  - users:read: Read data about users (people with access to a Pipedrive account), their permissions, roles and followers, as well as about teams.
  - base: Read settings of the authorized user and currencies in an account.
  - phone-integration: Create, read and delete call logs and its audio recordings.

