# Pipedrive::ActivitiesApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**activities_delete**](ActivitiesApi.md#activities_delete) | **DELETE** /activities | Delete multiple activities in bulk
[**activities_get**](ActivitiesApi.md#activities_get) | **GET** /activities | Get all activities assigned to a particular user
[**activities_id_delete**](ActivitiesApi.md#activities_id_delete) | **DELETE** /activities/{id} | Delete an activity
[**activities_id_get**](ActivitiesApi.md#activities_id_get) | **GET** /activities/{id} | Get details of an activity
[**activities_id_put**](ActivitiesApi.md#activities_id_put) | **PUT** /activities/{id} | Edit an activity
[**activities_post**](ActivitiesApi.md#activities_post) | **POST** /activities | Add an activity



## activities_delete

> activities_delete(ids)

Delete multiple activities in bulk

Marks multiple activities as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ActivitiesApi.new
ids = 'ids_example' # String | Comma-separated IDs that will be deleted

begin
  #Delete multiple activities in bulk
  api_instance.activities_delete(ids)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ActivitiesApi->activities_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated IDs that will be deleted | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## activities_get

> activities_get(opts)

Get all activities assigned to a particular user

Returns all activities assigned to a particular user.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ActivitiesApi.new
opts = {
  user_id: 56, # Integer | ID of the user whose activities will be fetched. If omitted, the user associated with the API token will be used. If 0, activities for all company users will be fetched based on the permission sets.
  filter_id: 56, # Integer | ID of the filter to use (will narrow down results if used together with user_id parameter).
  type: 'type_example', # String | Type of the activity, can be one type or multiple types separated by a comma. This is in correlation with the key_string parameter of ActivityTypes.
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  start_date: Date.parse('2013-10-20'), # Date | Use the activity due date where you wish to begin fetching activities from. Insert due date in YYYY-MM-DD format.
  end_date: Date.parse('2013-10-20'), # Date | Use the activity due date where you wish to stop fetching activities from. Insert due date in YYYY-MM-DD format.
  done: Pipedrive::NumberBoolean.new # NumberBoolean | Whether the activity is done or not. 0 = Not done, 1 = Done. If omitted returns both Done and Not done activities.
}

begin
  #Get all activities assigned to a particular user
  api_instance.activities_get(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ActivitiesApi->activities_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user_id** | **Integer**| ID of the user whose activities will be fetched. If omitted, the user associated with the API token will be used. If 0, activities for all company users will be fetched based on the permission sets. | [optional] 
 **filter_id** | **Integer**| ID of the filter to use (will narrow down results if used together with user_id parameter). | [optional] 
 **type** | **String**| Type of the activity, can be one type or multiple types separated by a comma. This is in correlation with the key_string parameter of ActivityTypes. | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **start_date** | **Date**| Use the activity due date where you wish to begin fetching activities from. Insert due date in YYYY-MM-DD format. | [optional] 
 **end_date** | **Date**| Use the activity due date where you wish to stop fetching activities from. Insert due date in YYYY-MM-DD format. | [optional] 
 **done** | [**NumberBoolean**](.md)| Whether the activity is done or not. 0 &#x3D; Not done, 1 &#x3D; Done. If omitted returns both Done and Not done activities. | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## activities_id_delete

> activities_id_delete(id)

Delete an activity

Deletes an activity.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ActivitiesApi.new
id = 56 # Integer | ID of the activity

begin
  #Delete an activity
  api_instance.activities_id_delete(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ActivitiesApi->activities_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the activity | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## activities_id_get

> activities_id_get(id)

Get details of an activity

Returns details of a specific activity.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ActivitiesApi.new
id = 56 # Integer | ID of the activity

begin
  #Get details of an activity
  api_instance.activities_id_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ActivitiesApi->activities_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the activity | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## activities_id_put

> activities_id_put(id, opts)

Edit an activity

Modifies an activity. Includes more_activities_scheduled_in_context property in response's additional_data which indicates whether there are more undone activities scheduled with the same deal, person or organization (depending on the supplied data).

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ActivitiesApi.new
id = 56 # Integer | ID of the activity
opts = {
  activity: Pipedrive::Activity.new # Activity | 
}

begin
  #Edit an activity
  api_instance.activities_id_put(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ActivitiesApi->activities_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the activity | 
 **activity** | [**Activity**](Activity.md)|  | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined


## activities_post

> activities_post(opts)

Add an activity

Adds a new activity. Includes more_activities_scheduled_in_context property in response's additional_data which indicates whether there are more undone activities scheduled with the same deal, person or organization (depending on the supplied data). For more information on how to add an activity, see <a href=\"https://pipedrive.readme.io/docs/adding-an-activity\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ActivitiesApi.new
opts = {
  activity: Pipedrive::Activity.new # Activity | 
}

begin
  #Add an activity
  api_instance.activities_post(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ActivitiesApi->activities_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **activity** | [**Activity**](Activity.md)|  | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined

