# Pipedrive::CallLogsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**call_logs_get**](CallLogsApi.md#call_logs_get) | **GET** /callLogs | Get all call logs assigned to a particular user
[**call_logs_id_delete**](CallLogsApi.md#call_logs_id_delete) | **DELETE** /callLogs/{id} | Delete a call log
[**call_logs_id_get**](CallLogsApi.md#call_logs_id_get) | **GET** /callLogs/{id} | Get details of a call log
[**call_logs_id_recordings_post**](CallLogsApi.md#call_logs_id_recordings_post) | **POST** /callLogs/{id}/recordings | Attach an audio file to the call log
[**call_logs_post**](CallLogsApi.md#call_logs_post) | **POST** /callLogs | Add a call log



## call_logs_get

> InlineResponse200 call_logs_get(opts)

Get all call logs assigned to a particular user

Returns all call logs assigned to a particular user

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::CallLogsApi.new
opts = {
  limit: 20, # Float | For pagination, the limit of entries to be returned
  start: 0 # Float | For pagination, the position that represents the first result for the page
}

begin
  #Get all call logs assigned to a particular user
  result = api_instance.call_logs_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling CallLogsApi->call_logs_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Float**| For pagination, the limit of entries to be returned | [optional] 
 **start** | **Float**| For pagination, the position that represents the first result for the page | [optional] 

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## call_logs_id_delete

> InlineResponse2003 call_logs_id_delete(id)

Delete a call log

Deletes a call log. If there is an audio recording attached to it, it will also be deleted. The related activity will not be removed by this request. If you want to remove the related activities, please use the endpoint which is specific for activities.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::CallLogsApi.new
id = '3cde3b05035cae14dcfc172bd8000d08' # String | The ID received when you create the call log

begin
  #Delete a call log
  result = api_instance.call_logs_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling CallLogsApi->call_logs_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The ID received when you create the call log | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## call_logs_id_get

> InlineResponse2002 call_logs_id_get(id)

Get details of a call log

Returns details of a specific call log

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::CallLogsApi.new
id = '3cde3b05035cae14dcfc172bd8000d08' # String | The ID received when you create the call log

begin
  #Get details of a call log
  result = api_instance.call_logs_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling CallLogsApi->call_logs_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The ID received when you create the call log | 

### Return type

[**InlineResponse2002**](InlineResponse2002.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## call_logs_id_recordings_post

> InlineResponse2003 call_logs_id_recordings_post(id, file)

Attach an audio file to the call log

Adds an audio recording to the call log. That audio can be played by those who have access to the call log object.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::CallLogsApi.new
id = '3cde3b05035cae14dcfc172bd8000d08' # String | The ID received when you create the call log
file = File.new('/path/to/file') # File | Audio file supported by the HTML5 specification

begin
  #Attach an audio file to the call log
  result = api_instance.call_logs_id_recordings_post(id, file)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling CallLogsApi->call_logs_id_recordings_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The ID received when you create the call log | 
 **file** | **File**| Audio file supported by the HTML5 specification | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: multipart/form-data
- **Accept**: application/json


## call_logs_post

> InlineResponse2001 call_logs_post(opts)

Add a call log

Adds a new call log

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::CallLogsApi.new
opts = {
  inline_object2: Pipedrive::InlineObject2.new # InlineObject2 | 
}

begin
  #Add a call log
  result = api_instance.call_logs_post(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling CallLogsApi->call_logs_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **inline_object2** | [**InlineObject2**](InlineObject2.md)|  | [optional] 

### Return type

[**InlineResponse2001**](InlineResponse2001.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

