# Pipedrive::DealFieldsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**deal_fields_delete**](DealFieldsApi.md#deal_fields_delete) | **DELETE** /dealFields | Delete multiple deal fields in bulk
[**deal_fields_get**](DealFieldsApi.md#deal_fields_get) | **GET** /dealFields | Get all deal fields
[**deal_fields_id_delete**](DealFieldsApi.md#deal_fields_id_delete) | **DELETE** /dealFields/{id} | Delete a deal field
[**deal_fields_id_get**](DealFieldsApi.md#deal_fields_id_get) | **GET** /dealFields/{id} | Get one deal field
[**deal_fields_id_put**](DealFieldsApi.md#deal_fields_id_put) | **PUT** /dealFields/{id} | Update a deal field
[**deal_fields_post**](DealFieldsApi.md#deal_fields_post) | **POST** /dealFields | Add a new deal field



## deal_fields_delete

> deal_fields_delete(ids)

Delete multiple deal fields in bulk

Marks multiple fields as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealFieldsApi.new
ids = 'ids_example' # String | Comma-separated field IDs to delete

begin
  #Delete multiple deal fields in bulk
  api_instance.deal_fields_delete(ids)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealFieldsApi->deal_fields_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated field IDs to delete | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deal_fields_get

> deal_fields_get(opts)

Get all deal fields

Returns data about all fields deals can have

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealFieldsApi.new
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #Get all deal fields
  api_instance.deal_fields_get(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealFieldsApi->deal_fields_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deal_fields_id_delete

> deal_fields_id_delete(id)

Delete a deal field

Marks a field as deleted. For more information on how to delete a custom field, see <a href=\"https://pipedrive.readme.io/docs/deleting-a-custom-field\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealFieldsApi.new
id = 56 # Integer | ID of the field

begin
  #Delete a deal field
  api_instance.deal_fields_id_delete(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealFieldsApi->deal_fields_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the field | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deal_fields_id_get

> deal_fields_id_get(id)

Get one deal field

Returns data about a specific deal field.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealFieldsApi.new
id = 56 # Integer | ID of the field

begin
  #Get one deal field
  api_instance.deal_fields_id_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealFieldsApi->deal_fields_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the field | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deal_fields_id_put

> deal_fields_id_put(id, name, opts)

Update a deal field

Updates a deal field. See an example of updating custom fields’ values in <a href=\" https://pipedrive.readme.io/docs/updating-custom-field-value \" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealFieldsApi.new
id = 56 # Integer | ID of the field
name = 'name_example' # String | Name of the field
opts = {
  options: 'options_example' # String | When field_type is either set or enum, possible options must be supplied as a JSON-encoded sequential array, for example: [\\\"red\\\",\\\"blue\\\",\\\"lilac\\\"]
}

begin
  #Update a deal field
  api_instance.deal_fields_id_put(id, name, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealFieldsApi->deal_fields_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the field | 
 **name** | **String**| Name of the field | 
 **options** | **String**| When field_type is either set or enum, possible options must be supplied as a JSON-encoded sequential array, for example: [\\\&quot;red\\\&quot;,\\\&quot;blue\\\&quot;,\\\&quot;lilac\\\&quot;] | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## deal_fields_post

> deal_fields_post

Add a new deal field

Adds a new deal field. For more information on adding a new custom field, see <a href=\"https://pipedrive.readme.io/docs/adding-a-new-custom-field\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealFieldsApi.new

begin
  #Add a new deal field
  api_instance.deal_fields_post
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealFieldsApi->deal_fields_post: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined

