# Pipedrive::DealsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**deals_delete**](DealsApi.md#deals_delete) | **DELETE** /deals | Delete multiple deals in bulk
[**deals_find_get**](DealsApi.md#deals_find_get) | **GET** /deals/find | Find deals by name
[**deals_get**](DealsApi.md#deals_get) | **GET** /deals | Get all deals
[**deals_id_activities_get**](DealsApi.md#deals_id_activities_get) | **GET** /deals/{id}/activities | List activities associated with a deal
[**deals_id_delete**](DealsApi.md#deals_id_delete) | **DELETE** /deals/{id} | Delete a deal
[**deals_id_duplicate_post**](DealsApi.md#deals_id_duplicate_post) | **POST** /deals/{id}/duplicate | Duplicate deal
[**deals_id_files_get**](DealsApi.md#deals_id_files_get) | **GET** /deals/{id}/files | List files attached to a deal
[**deals_id_flow_get**](DealsApi.md#deals_id_flow_get) | **GET** /deals/{id}/flow | List updates about a deal
[**deals_id_followers_follower_id_delete**](DealsApi.md#deals_id_followers_follower_id_delete) | **DELETE** /deals/{id}/followers/{follower_id} | Delete a follower from a deal
[**deals_id_followers_get**](DealsApi.md#deals_id_followers_get) | **GET** /deals/{id}/followers | List followers of a deal
[**deals_id_followers_post**](DealsApi.md#deals_id_followers_post) | **POST** /deals/{id}/followers | Add a follower to a deal
[**deals_id_get**](DealsApi.md#deals_id_get) | **GET** /deals/{id} | Get details of a deal
[**deals_id_mail_messages_get**](DealsApi.md#deals_id_mail_messages_get) | **GET** /deals/{id}/mailMessages | List mail messages associated with a deal
[**deals_id_merge_put**](DealsApi.md#deals_id_merge_put) | **PUT** /deals/{id}/merge | Merge two deals
[**deals_id_participants_deal_participant_id_delete**](DealsApi.md#deals_id_participants_deal_participant_id_delete) | **DELETE** /deals/{id}/participants/{deal_participant_id} | Delete a participant from a deal
[**deals_id_participants_get**](DealsApi.md#deals_id_participants_get) | **GET** /deals/{id}/participants | List participants of a deal
[**deals_id_participants_post**](DealsApi.md#deals_id_participants_post) | **POST** /deals/{id}/participants | Add a participant to a deal
[**deals_id_permitted_users_get**](DealsApi.md#deals_id_permitted_users_get) | **GET** /deals/{id}/permittedUsers | List permitted users
[**deals_id_persons_get**](DealsApi.md#deals_id_persons_get) | **GET** /deals/{id}/persons | List all persons associated with a deal
[**deals_id_products_get**](DealsApi.md#deals_id_products_get) | **GET** /deals/{id}/products | List products attached to a deal
[**deals_id_products_post**](DealsApi.md#deals_id_products_post) | **POST** /deals/{id}/products | Add a product to the deal, eventually creating a new item called a deal-product
[**deals_id_products_product_attachment_id_delete**](DealsApi.md#deals_id_products_product_attachment_id_delete) | **DELETE** /deals/{id}/products/{product_attachment_id} | Delete an attached product from a deal
[**deals_id_products_product_attachment_id_put**](DealsApi.md#deals_id_products_product_attachment_id_put) | **PUT** /deals/{id}/products/{product_attachment_id} | Update product attachment details of the deal-product (a product already attached to a deal)
[**deals_id_put**](DealsApi.md#deals_id_put) | **PUT** /deals/{id} | Update a deal
[**deals_post**](DealsApi.md#deals_post) | **POST** /deals | Add a deal
[**deals_search_get**](DealsApi.md#deals_search_get) | **GET** /deals/search | Search deals
[**deals_summary_get**](DealsApi.md#deals_summary_get) | **GET** /deals/summary | Get deals summary
[**deals_timeline_get**](DealsApi.md#deals_timeline_get) | **GET** /deals/timeline | Get deals timeline



## deals_delete

> DeleteMultipleDeals deals_delete(ids)

Delete multiple deals in bulk

Marks multiple deals as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
ids = 'ids_example' # String | Comma-separated IDs that will be deleted

begin
  #Delete multiple deals in bulk
  result = api_instance.deals_delete(ids)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated IDs that will be deleted | 

### Return type

[**DeleteMultipleDeals**](DeleteMultipleDeals.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_find_get

> GetDealsByName deals_find_get(term, opts)

Find deals by name

<strong>This endpoint is deprecated. Please use <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/Deals/get_deals_search\">/v1/deals/search</a> or <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/ItemSearch/get_itemSearch\">/v1/itemSearch</a> instead</strong>. <br> Searches all deals by their title.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
term = 'term_example' # String | Search term to look for
opts = {
  person_id: 56, # Integer | ID of the person the Deal is associated with.
  org_id: 56 # Integer | ID of the organization the Deal is associated with.
}

begin
  #Find deals by name
  result = api_instance.deals_find_get(term, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_find_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| Search term to look for | 
 **person_id** | **Integer**| ID of the person the Deal is associated with. | [optional] 
 **org_id** | **Integer**| ID of the organization the Deal is associated with. | [optional] 

### Return type

[**GetDealsByName**](GetDealsByName.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_get

> GetDeals deals_get(opts)

Get all deals

Returns all deals. For more information on how to get all deals, see <a href=\"https://pipedrive.readme.io/docs/getting-all-deals\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
opts = {
  user_id: 56, # Integer | If supplied, only deals matching the given user will be returned.
  filter_id: 56, # Integer | ID of the filter to use
  stage_id: 56, # Integer | If supplied, only deals within the given stage will be returned.
  status: 'all_not_deleted', # String | Only fetch deals with specific status. If omitted, all not deleted deals are fetched.
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  sort: 'sort_example', # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys).
  owned_by_you: Pipedrive::NumberBoolean.new # NumberBoolean | When supplied, only deals owned by you are returned. However filter_id takes precedence over owned_by_you when both are supplied.
}

begin
  #Get all deals
  result = api_instance.deals_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user_id** | **Integer**| If supplied, only deals matching the given user will be returned. | [optional] 
 **filter_id** | **Integer**| ID of the filter to use | [optional] 
 **stage_id** | **Integer**| If supplied, only deals within the given stage will be returned. | [optional] 
 **status** | **String**| Only fetch deals with specific status. If omitted, all not deleted deals are fetched. | [optional] [default to &#39;all_not_deleted&#39;]
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). | [optional] 
 **owned_by_you** | [**NumberBoolean**](.md)| When supplied, only deals owned by you are returned. However filter_id takes precedence over owned_by_you when both are supplied. | [optional] 

### Return type

[**GetDeals**](GetDeals.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_id_activities_get

> deals_id_activities_get(id, opts)

List activities associated with a deal

Lists activities associated with a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  done: Pipedrive::NumberBoolean.new, # NumberBoolean | Whether the activity is done or not. 0 = Not done, 1 = Done. If omitted returns both Done and Not done activities.
  exclude: 'exclude_example' # String | A comma-separated string of activity IDs to exclude from result
}

begin
  #List activities associated with a deal
  api_instance.deals_id_activities_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_activities_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **done** | [**NumberBoolean**](.md)| Whether the activity is done or not. 0 &#x3D; Not done, 1 &#x3D; Done. If omitted returns both Done and Not done activities. | [optional] 
 **exclude** | **String**| A comma-separated string of activity IDs to exclude from result | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_delete

> DeleteDeal deals_id_delete(id)

Delete a deal

Marks a deal as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal

begin
  #Delete a deal
  result = api_instance.deals_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 

### Return type

[**DeleteDeal**](DeleteDeal.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_id_duplicate_post

> GetDuplicatedDeal deals_id_duplicate_post(id)

Duplicate deal

Duplicate a deal

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal

begin
  #Duplicate deal
  result = api_instance.deals_id_duplicate_post(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_duplicate_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 

### Return type

[**GetDuplicatedDeal**](GetDuplicatedDeal.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_id_files_get

> deals_id_files_get(id, opts)

List files attached to a deal

Lists files associated with a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  include_deleted_files: Pipedrive::NumberBoolean.new, # NumberBoolean | When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work.
  sort: 'sort_example' # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment.
}

begin
  #List files attached to a deal
  api_instance.deals_id_files_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_files_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **include_deleted_files** | [**NumberBoolean**](.md)| When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work. | [optional] 
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment. | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_flow_get

> deals_id_flow_get(id, opts)

List updates about a deal

Lists updates about a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  all_changes: 'all_changes_example', # String | Whether to show custom field updates or not. 1 = Include custom field changes. If omitted returns changes without custom field updates.
  items: 'items_example' # String | A comma-separated string for filtering out item specific updates. (Possible values - activity, plannedActivity, note, file, change, deal, follower, participant, mailMessage, mailMessageWithAttachment, invoice, activityFile, document)
}

begin
  #List updates about a deal
  api_instance.deals_id_flow_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_flow_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **all_changes** | **String**| Whether to show custom field updates or not. 1 &#x3D; Include custom field changes. If omitted returns changes without custom field updates. | [optional] 
 **items** | **String**| A comma-separated string for filtering out item specific updates. (Possible values - activity, plannedActivity, note, file, change, deal, follower, participant, mailMessage, mailMessageWithAttachment, invoice, activityFile, document) | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_followers_follower_id_delete

> DeleteDealFollower deals_id_followers_follower_id_delete(id, follower_id)

Delete a follower from a deal

Deletes a follower from a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
follower_id = 56 # Integer | ID of the follower

begin
  #Delete a follower from a deal
  result = api_instance.deals_id_followers_follower_id_delete(id, follower_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_followers_follower_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **follower_id** | **Integer**| ID of the follower | 

### Return type

[**DeleteDealFollower**](DeleteDealFollower.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_id_followers_get

> deals_id_followers_get(id)

List followers of a deal

Lists the followers of a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal

begin
  #List followers of a deal
  api_instance.deals_id_followers_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_followers_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_followers_post

> AddedDealFollower deals_id_followers_post(id, user_id)

Add a follower to a deal

Adds a follower to a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
user_id = 56 # Integer | ID of the user

begin
  #Add a follower to a deal
  result = api_instance.deals_id_followers_post(id, user_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_followers_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **user_id** | **Integer**| ID of the user | 

### Return type

[**AddedDealFollower**](AddedDealFollower.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## deals_id_get

> GetDeal deals_id_get(id)

Get details of a deal

Returns details of a specific deal. Note that this also returns some additional fields which are not present when asking for all deals – such as deal age and stay in pipeline stages. Also note that custom fields appear as long hashes in the resulting data. These hashes can be mapped against the 'key' value of dealFields. For more information on how to get all details of a deal, see <a href=\"https://pipedrive.readme.io/docs/getting-details-of-a-deal\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal

begin
  #Get details of a deal
  result = api_instance.deals_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 

### Return type

[**GetDeal**](GetDeal.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_id_mail_messages_get

> deals_id_mail_messages_get(id, opts)

List mail messages associated with a deal

Lists mail messages associated with a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List mail messages associated with a deal
  api_instance.deals_id_mail_messages_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_mail_messages_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_merge_put

> GetMergedDeal deals_id_merge_put(id, merge_with_id)

Merge two deals

Merges a deal with another deal. For more information on how to merge two deals, see <a href=\"https://pipedrive.readme.io/docs/merging-two-deals\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
merge_with_id = 56 # Integer | ID of the deal that the deal will be merged with

begin
  #Merge two deals
  result = api_instance.deals_id_merge_put(id, merge_with_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_merge_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **merge_with_id** | **Integer**| ID of the deal that the deal will be merged with | 

### Return type

[**GetMergedDeal**](GetMergedDeal.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## deals_id_participants_deal_participant_id_delete

> DeleteDealParticipant deals_id_participants_deal_participant_id_delete(id, deal_participant_id)

Delete a participant from a deal

Deletes a participant from a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
deal_participant_id = 56 # Integer | ID of the deal participant

begin
  #Delete a participant from a deal
  result = api_instance.deals_id_participants_deal_participant_id_delete(id, deal_participant_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_participants_deal_participant_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **deal_participant_id** | **Integer**| ID of the deal participant | 

### Return type

[**DeleteDealParticipant**](DeleteDealParticipant.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_id_participants_get

> deals_id_participants_get(id, opts)

List participants of a deal

Lists participants associated with a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List participants of a deal
  api_instance.deals_id_participants_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_participants_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_participants_post

> deals_id_participants_post(id, person_id)

Add a participant to a deal

Adds a participant to a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
person_id = 56 # Integer | ID of the person

begin
  #Add a participant to a deal
  api_instance.deals_id_participants_post(id, person_id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_participants_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **person_id** | **Integer**| ID of the person | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## deals_id_permitted_users_get

> deals_id_permitted_users_get(id)

List permitted users

List users permitted to access a deal

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal

begin
  #List permitted users
  api_instance.deals_id_permitted_users_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_permitted_users_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_persons_get

> deals_id_persons_get(id, opts)

List all persons associated with a deal

Lists all persons associated with a deal, regardless of whether the person is the primary contact of the deal, or added as a participant.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List all persons associated with a deal
  api_instance.deals_id_persons_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_persons_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_products_get

> deals_id_products_get(id, opts)

List products attached to a deal

Lists products attached to a deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  include_product_data: Pipedrive::NumberBoolean.new # NumberBoolean | Whether to fetch product data along with each attached product (1) or not (0, default).
}

begin
  #List products attached to a deal
  api_instance.deals_id_products_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_products_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **include_product_data** | [**NumberBoolean**](.md)| Whether to fetch product data along with each attached product (1) or not (0, default). | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## deals_id_products_post

> GetAddProductAttachementDetails deals_id_products_post(id, opts)

Add a product to the deal, eventually creating a new item called a deal-product

Adds a product to the deal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  new_deal_product: Pipedrive::NewDealProduct.new # NewDealProduct | 
}

begin
  #Add a product to the deal, eventually creating a new item called a deal-product
  result = api_instance.deals_id_products_post(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_products_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **new_deal_product** | [**NewDealProduct**](NewDealProduct.md)|  | [optional] 

### Return type

[**GetAddProductAttachementDetails**](GetAddProductAttachementDetails.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deals_id_products_product_attachment_id_delete

> DeleteDealProduct deals_id_products_product_attachment_id_delete(id, product_attachment_id)

Delete an attached product from a deal

Deletes a product attachment from a deal, using the product_attachment_id.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
product_attachment_id = 56 # Integer | Product attachment ID. This is returned as product_attachment_id after attaching a product to a deal or as id when listing the products attached to a deal.

begin
  #Delete an attached product from a deal
  result = api_instance.deals_id_products_product_attachment_id_delete(id, product_attachment_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_products_product_attachment_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **product_attachment_id** | **Integer**| Product attachment ID. This is returned as product_attachment_id after attaching a product to a deal or as id when listing the products attached to a deal. | 

### Return type

[**DeleteDealProduct**](DeleteDealProduct.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_id_products_product_attachment_id_put

> GetProductAttachementDetails deals_id_products_product_attachment_id_put(id, product_attachment_id, opts)

Update product attachment details of the deal-product (a product already attached to a deal)

Updates product attachment details.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
product_attachment_id = 56 # Integer | ID of the deal-product (the ID of the product attached to the deal)
opts = {
  basic_deal_product: Pipedrive::BasicDealProduct.new # BasicDealProduct | 
}

begin
  #Update product attachment details of the deal-product (a product already attached to a deal)
  result = api_instance.deals_id_products_product_attachment_id_put(id, product_attachment_id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_products_product_attachment_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **product_attachment_id** | **Integer**| ID of the deal-product (the ID of the product attached to the deal) | 
 **basic_deal_product** | [**BasicDealProduct**](BasicDealProduct.md)|  | [optional] 

### Return type

[**GetProductAttachementDetails**](GetProductAttachementDetails.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## deals_id_put

> GetAddedDeal deals_id_put(id, opts)

Update a deal

Updates the properties of a deal. For more information on how to update a deal, see <a href=\"https://pipedrive.readme.io/docs/updating-a-deal\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
id = 56 # Integer | ID of the deal
opts = {
  title: 'title_example', # String | Deal title
  value: 'value_example', # String | Value of the deal. If omitted, value will be set to 0.
  currency: 'currency_example', # String | Currency of the deal. Accepts a 3-character currency code. If omitted, currency will be set to the default currency of the authorized user.
  user_id: 56, # Integer | ID of the user who will be marked as the owner of this deal. If omitted, the authorized user ID will be used.
  person_id: 56, # Integer | ID of the person this deal will be associated with
  org_id: 56, # Integer | ID of the organization this deal will be associated with
  stage_id: 56, # Integer | ID of the stage this deal will be placed in a pipeline (note that you can't supply the ID of the pipeline as this will be assigned automatically based on stage_id). If omitted, the deal will be placed in the first stage of the default pipeline.
  status: 'status_example', # String | open = Open, won = Won, lost = Lost, deleted = Deleted. If omitted, status will be set to open.
  probability: 3.4, # Float | Deal success probability percentage. Used/shown only when deal_probability for the pipeline of the deal is enabled.
  lost_reason: 'lost_reason_example', # String | Optional message about why the deal was lost (to be used when status=lost)
  visible_to: Pipedrive::VisibleTo.new # VisibleTo | Visibility of the deal. If omitted, visibility will be set to the default visibility setting of this item type for the authorized user.<dl class=\\\"fields-list\\\"><dt>1</dt><dd>Owner &amp; followers (private)</dd><dt>3</dt><dd>Entire company (shared)</dd></dl>
}

begin
  #Update a deal
  result = api_instance.deals_id_put(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the deal | 
 **title** | **String**| Deal title | [optional] 
 **value** | **String**| Value of the deal. If omitted, value will be set to 0. | [optional] 
 **currency** | **String**| Currency of the deal. Accepts a 3-character currency code. If omitted, currency will be set to the default currency of the authorized user. | [optional] 
 **user_id** | **Integer**| ID of the user who will be marked as the owner of this deal. If omitted, the authorized user ID will be used. | [optional] 
 **person_id** | **Integer**| ID of the person this deal will be associated with | [optional] 
 **org_id** | **Integer**| ID of the organization this deal will be associated with | [optional] 
 **stage_id** | **Integer**| ID of the stage this deal will be placed in a pipeline (note that you can&#39;t supply the ID of the pipeline as this will be assigned automatically based on stage_id). If omitted, the deal will be placed in the first stage of the default pipeline. | [optional] 
 **status** | **String**| open &#x3D; Open, won &#x3D; Won, lost &#x3D; Lost, deleted &#x3D; Deleted. If omitted, status will be set to open. | [optional] 
 **probability** | **Float**| Deal success probability percentage. Used/shown only when deal_probability for the pipeline of the deal is enabled. | [optional] 
 **lost_reason** | **String**| Optional message about why the deal was lost (to be used when status&#x3D;lost) | [optional] 
 **visible_to** | [**VisibleTo**](VisibleTo.md)| Visibility of the deal. If omitted, visibility will be set to the default visibility setting of this item type for the authorized user.&lt;dl class&#x3D;\\\&quot;fields-list\\\&quot;&gt;&lt;dt&gt;1&lt;/dt&gt;&lt;dd&gt;Owner &amp;amp; followers (private)&lt;/dd&gt;&lt;dt&gt;3&lt;/dt&gt;&lt;dd&gt;Entire company (shared)&lt;/dd&gt;&lt;/dl&gt; | [optional] 

### Return type

[**GetAddedDeal**](GetAddedDeal.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## deals_post

> GetAddedDeal deals_post

Add a deal

Adds a new deal. Note that you can supply additional custom fields along with the request that are not described here. These custom fields are different for each Pipedrive account and can be recognized by long hashes as keys. To determine which custom fields exists, fetch the dealFields and look for 'key' values. For more information on how to add a deal, see <a href=\"https://pipedrive.readme.io/docs/creating-a-deal\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new

begin
  #Add a deal
  result = api_instance.deals_post
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_post: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**GetAddedDeal**](GetAddedDeal.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## deals_search_get

> BaseResponse deals_search_get(term, opts)

Search deals

Searches all Deals by title, notes and/or custom fields. This endpoint is a wrapper of <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/ItemSearch/get_itemSearch\">/v1/itemSearch</a> with a narrower OAuth scope. Found Deals can be filtered by Person ID and Organization ID.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
term = 'term_example' # String | The search term to look for. Minimum 2 characters (or 1 if using exact_match).
opts = {
  fields: 'fields_example', # String | A comma-separated string array. The fields to perform the search from. Defaults to all of them.
  exact_match: true, # Boolean | When enabled, only full exact matches against the given term are returned. It is <b>not</b> case sensitive.
  person_id: 56, # Integer | Will filter Deals by the provided Person ID. The upper limit of found Deals associated with the Person is 2000.
  organization_id: 56, # Integer | Will filter Deals by the provided Organization ID. The upper limit of found Deals associated with the Organization is 2000.
  status: 'status_example', # String | Will filter Deals by the provided specific status. open = Open, won = Won, lost = Lost. The upper limit of found Deals associated with the status is 2000.
  include_fields: 'include_fields_example', # String | Supports including optional fields in the results which are not provided by default.
  start: 0, # Integer | Pagination start. Note that the pagination is based on main results and does not include related items when using search_for_related_items parameter.
  limit: 56 # Integer | Items shown per page
}

begin
  #Search deals
  result = api_instance.deals_search_get(term, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_search_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| The search term to look for. Minimum 2 characters (or 1 if using exact_match). | 
 **fields** | **String**| A comma-separated string array. The fields to perform the search from. Defaults to all of them. | [optional] 
 **exact_match** | **Boolean**| When enabled, only full exact matches against the given term are returned. It is &lt;b&gt;not&lt;/b&gt; case sensitive. | [optional] 
 **person_id** | **Integer**| Will filter Deals by the provided Person ID. The upper limit of found Deals associated with the Person is 2000. | [optional] 
 **organization_id** | **Integer**| Will filter Deals by the provided Organization ID. The upper limit of found Deals associated with the Organization is 2000. | [optional] 
 **status** | **String**| Will filter Deals by the provided specific status. open &#x3D; Open, won &#x3D; Won, lost &#x3D; Lost. The upper limit of found Deals associated with the status is 2000. | [optional] 
 **include_fields** | **String**| Supports including optional fields in the results which are not provided by default. | [optional] 
 **start** | **Integer**| Pagination start. Note that the pagination is based on main results and does not include related items when using search_for_related_items parameter. | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_summary_get

> GetDealsSummary deals_summary_get(opts)

Get deals summary

Returns summary of all the deals.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
opts = {
  status: 'status_example', # String | Only fetch deals with specific status. open = Open, won = Won, lost = Lost
  filter_id: 56, # Integer | user_id will not be considered. Only deals matching the given filter will be returned.
  user_id: 56, # Integer | Only deals matching the given user will be returned. user_id will not be considered if you use filter_id.
  stage_id: 56 # Integer | Only deals within the given stage will be returned.
}

begin
  #Get deals summary
  result = api_instance.deals_summary_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_summary_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **status** | **String**| Only fetch deals with specific status. open &#x3D; Open, won &#x3D; Won, lost &#x3D; Lost | [optional] 
 **filter_id** | **Integer**| user_id will not be considered. Only deals matching the given filter will be returned. | [optional] 
 **user_id** | **Integer**| Only deals matching the given user will be returned. user_id will not be considered if you use filter_id. | [optional] 
 **stage_id** | **Integer**| Only deals within the given stage will be returned. | [optional] 

### Return type

[**GetDealsSummary**](GetDealsSummary.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## deals_timeline_get

> GetDealsTimeline deals_timeline_get(start_date, interval, amount, field_key, opts)

Get deals timeline

Returns open and won deals, grouped by defined interval of time set in a date-type dealField (field_key) — e.g. when month is the chosen interval, and 3 months are asked starting from  January 1st, 2012, deals are returned grouped into 3 groups — January, February and March — based on the value of the given field_key.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::DealsApi.new
start_date = Date.parse('2013-10-20') # Date | Date where the first interval starts. Format: YYYY-MM-DD
interval = 'interval_example' # String | The type of interval<dl class=\"fields-list\"><dt>day</dt><dd>Day</dd><dt>week</dt><dd>A full week (7 days) starting from start_date</dd><dt>month</dt><dd>A full month (depending on the number of days in given month) starting from start_date</dd><dt>quarter</dt><dd>A full quarter (3 months) starting from start_date</dd></dl>
amount = 56 # Integer | The number of given intervals, starting from start_date, to fetch. E.g. 3 (months).
field_key = 'field_key_example' # String | The date field key which deals will be retrieved from
opts = {
  user_id: 56, # Integer | If supplied, only deals matching the given user will be returned.
  pipeline_id: 56, # Integer | If supplied, only deals matching the given pipeline will be returned
  filter_id: 56, # Integer | If supplied, only deals matching the given filter will be returned
  exclude_deals: Pipedrive::NumberBoolean.new, # NumberBoolean | Whether to exclude deals list (1) or not (0). Note that when deals are excluded, the timeline summary (counts and values) is still returned.
  totals_convert_currency: 'totals_convert_currency_example' # String | 3-letter currency code of any of the supported currencies. When supplied, totals_converted is returned per each interval which contains the currency-converted total amounts in the given currency. You may also set this parameter to 'default_currency' in which case users default currency is used.
}

begin
  #Get deals timeline
  result = api_instance.deals_timeline_get(start_date, interval, amount, field_key, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling DealsApi->deals_timeline_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **start_date** | **Date**| Date where the first interval starts. Format: YYYY-MM-DD | 
 **interval** | **String**| The type of interval&lt;dl class&#x3D;\&quot;fields-list\&quot;&gt;&lt;dt&gt;day&lt;/dt&gt;&lt;dd&gt;Day&lt;/dd&gt;&lt;dt&gt;week&lt;/dt&gt;&lt;dd&gt;A full week (7 days) starting from start_date&lt;/dd&gt;&lt;dt&gt;month&lt;/dt&gt;&lt;dd&gt;A full month (depending on the number of days in given month) starting from start_date&lt;/dd&gt;&lt;dt&gt;quarter&lt;/dt&gt;&lt;dd&gt;A full quarter (3 months) starting from start_date&lt;/dd&gt;&lt;/dl&gt; | 
 **amount** | **Integer**| The number of given intervals, starting from start_date, to fetch. E.g. 3 (months). | 
 **field_key** | **String**| The date field key which deals will be retrieved from | 
 **user_id** | **Integer**| If supplied, only deals matching the given user will be returned. | [optional] 
 **pipeline_id** | **Integer**| If supplied, only deals matching the given pipeline will be returned | [optional] 
 **filter_id** | **Integer**| If supplied, only deals matching the given filter will be returned | [optional] 
 **exclude_deals** | [**NumberBoolean**](.md)| Whether to exclude deals list (1) or not (0). Note that when deals are excluded, the timeline summary (counts and values) is still returned. | [optional] 
 **totals_convert_currency** | **String**| 3-letter currency code of any of the supported currencies. When supplied, totals_converted is returned per each interval which contains the currency-converted total amounts in the given currency. You may also set this parameter to &#39;default_currency&#39; in which case users default currency is used. | [optional] 

### Return type

[**GetDealsTimeline**](GetDealsTimeline.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

