# Pipedrive::FilesApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**files_get**](FilesApi.md#files_get) | **GET** /files | Get all files
[**files_id_delete**](FilesApi.md#files_id_delete) | **DELETE** /files/{id} | Delete a file
[**files_id_download_get**](FilesApi.md#files_id_download_get) | **GET** /files/{id}/download | Download one file
[**files_id_get**](FilesApi.md#files_id_get) | **GET** /files/{id} | Get one file
[**files_id_put**](FilesApi.md#files_id_put) | **PUT** /files/{id} | Update file details
[**files_post**](FilesApi.md#files_post) | **POST** /files | Add file
[**files_remote_link_post**](FilesApi.md#files_remote_link_post) | **POST** /files/remoteLink | Link a remote file to an item
[**files_remote_post**](FilesApi.md#files_remote_post) | **POST** /files/remote | Create a remote file and link it to an item



## files_get

> GetAllFiles files_get(opts)

Get all files

Returns data about all files.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FilesApi.new
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  include_deleted_files: Pipedrive::NumberBoolean.new, # NumberBoolean | When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work.
  sort: 'sort_example' # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment.
}

begin
  #Get all files
  result = api_instance.files_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **include_deleted_files** | [**NumberBoolean**](.md)| When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work. | [optional] 
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment. | [optional] 

### Return type

[**GetAllFiles**](GetAllFiles.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## files_id_delete

> DeleteFile files_id_delete(id)

Delete a file

Marks a file as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::FilesApi.new
id = 56 # Integer | ID of the file

begin
  #Delete a file
  result = api_instance.files_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the file | 

### Return type

[**DeleteFile**](DeleteFile.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## files_id_download_get

> File files_id_download_get(id)

Download one file

Initializes a file download.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FilesApi.new
id = 56 # Integer | ID of the file

begin
  #Download one file
  result = api_instance.files_id_download_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_id_download_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the file | 

### Return type

**File**

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/octet-stream


## files_id_get

> GetOneFile files_id_get(id)

Get one file

Returns data about a specific file.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FilesApi.new
id = 56 # Integer | ID of the file

begin
  #Get one file
  result = api_instance.files_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the file | 

### Return type

[**GetOneFile**](GetOneFile.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## files_id_put

> UpdateFile files_id_put(id, opts)

Update file details

Updates the properties of a file.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FilesApi.new
id = 56 # Integer | ID of the file
opts = {
  name: 'name_example', # String | Visible name of the file
  description: 'description_example' # String | Description of the file
}

begin
  #Update file details
  result = api_instance.files_id_put(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the file | 
 **name** | **String**| Visible name of the file | [optional] 
 **description** | **String**| Description of the file | [optional] 

### Return type

[**UpdateFile**](UpdateFile.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## files_post

> AddFile files_post(file, opts)

Add file

Lets you upload a file and associate it with Deal, Person, Organization, Activity or Product. For more information on how to add a file, see <a href=\"https://pipedrive.readme.io/docs/adding-a-file\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FilesApi.new
file = File.new('/path/to/file') # File | A single file, supplied in the multipart/form-data encoding and contained within the given boundaries.
opts = {
  deal_id: 56, # Integer | ID of the deal to associate file(s) with
  person_id: 56, # Integer | ID of the person to associate file(s) with
  org_id: 56, # Integer | ID of the organization to associate file(s) with
  product_id: 56, # Integer | ID of the product to associate file(s) with
  activity_id: 56 # Integer | ID of the activity to associate file(s) with
}

begin
  #Add file
  result = api_instance.files_post(file, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file** | **File**| A single file, supplied in the multipart/form-data encoding and contained within the given boundaries. | 
 **deal_id** | **Integer**| ID of the deal to associate file(s) with | [optional] 
 **person_id** | **Integer**| ID of the person to associate file(s) with | [optional] 
 **org_id** | **Integer**| ID of the organization to associate file(s) with | [optional] 
 **product_id** | **Integer**| ID of the product to associate file(s) with | [optional] 
 **activity_id** | **Integer**| ID of the activity to associate file(s) with | [optional] 

### Return type

[**AddFile**](AddFile.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: multipart/form-data
- **Accept**: application/json


## files_remote_link_post

> LinkRemoteFileToItem files_remote_link_post(item_type, item_id, remote_id, remote_location)

Link a remote file to an item

Links an existing remote file (googledrive) to the item you supply. For more information on how to link a remote file, see <a href=\"https://pipedrive.readme.io/docs/adding-a-remote-file\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FilesApi.new
item_type = 'item_type_example' # String | The item type
item_id = 56 # Integer | ID of the item to associate the file with
remote_id = 'remote_id_example' # String | The remote item id
remote_location = 'remote_location_example' # String | The location type to send the file to. Only googledrive is supported at the moment.

begin
  #Link a remote file to an item
  result = api_instance.files_remote_link_post(item_type, item_id, remote_id, remote_location)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_remote_link_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **item_type** | **String**| The item type | 
 **item_id** | **Integer**| ID of the item to associate the file with | 
 **remote_id** | **String**| The remote item id | 
 **remote_location** | **String**| The location type to send the file to. Only googledrive is supported at the moment. | 

### Return type

[**LinkRemoteFileToItem**](LinkRemoteFileToItem.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## files_remote_post

> CreateRemoteFileAndLinkItToItem files_remote_post(file_type, title, item_type, item_id, remote_location)

Create a remote file and link it to an item

Creates a new empty file in the remote location (googledrive) that will be linked to the item you supply. For more information on how to add a remote file, see <a href=\"https://pipedrive.readme.io/docs/adding-a-remote-file\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FilesApi.new
file_type = 'file_type_example' # String | The file type
title = 'title_example' # String | The title of the file
item_type = 'item_type_example' # String | The item type
item_id = 56 # Integer | ID of the item to associate the file with
remote_location = 'remote_location_example' # String | The location type to send the file to. Only googledrive is supported at the moment.

begin
  #Create a remote file and link it to an item
  result = api_instance.files_remote_post(file_type, title, item_type, item_id, remote_location)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FilesApi->files_remote_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_type** | **String**| The file type | 
 **title** | **String**| The title of the file | 
 **item_type** | **String**| The item type | 
 **item_id** | **Integer**| ID of the item to associate the file with | 
 **remote_location** | **String**| The location type to send the file to. Only googledrive is supported at the moment. | 

### Return type

[**CreateRemoteFileAndLinkItToItem**](CreateRemoteFileAndLinkItToItem.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json

