# Pipedrive::FiltersApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**filters_delete**](FiltersApi.md#filters_delete) | **DELETE** /filters | Delete multiple filters in bulk
[**filters_get**](FiltersApi.md#filters_get) | **GET** /filters | Get all filters
[**filters_helpers_get**](FiltersApi.md#filters_helpers_get) | **GET** /filters/helpers | Get all filter helpers
[**filters_id_delete**](FiltersApi.md#filters_id_delete) | **DELETE** /filters/{id} | Delete a filter
[**filters_id_get**](FiltersApi.md#filters_id_get) | **GET** /filters/{id} | Get one filter
[**filters_id_put**](FiltersApi.md#filters_id_put) | **PUT** /filters/{id} | Update filter
[**filters_post**](FiltersApi.md#filters_post) | **POST** /filters | Add a new filter



## filters_delete

> BaseResponse filters_delete(ids)

Delete multiple filters in bulk

Marks multiple filters as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FiltersApi.new
ids = 'ids_example' # String | Comma-separated filter IDs to delete

begin
  #Delete multiple filters in bulk
  result = api_instance.filters_delete(ids)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FiltersApi->filters_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated filter IDs to delete | 

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## filters_get

> BaseResponse filters_get(opts)

Get all filters

Returns data about all filters.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FiltersApi.new
opts = {
  type: Pipedrive::FilterType.new # FilterType | The types of filters to fetch
}

begin
  #Get all filters
  result = api_instance.filters_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FiltersApi->filters_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **type** | [**FilterType**](.md)| The types of filters to fetch | [optional] 

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## filters_helpers_get

> Object filters_helpers_get

Get all filter helpers

Returns all supported filter helpers. It helps to know what conditions and helpers are available when you want to <a href=\"/docs/api/v1/#!/Filters/post_filters\">add</a> or <a href=\"/docs/api/v1/#!/Filters/put_filters_id\">update</a> filters. For more information on how filter’s helpers can be used, see <a href=\"https://pipedrive.readme.io/docs/adding-a-filter\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::FiltersApi.new

begin
  #Get all filter helpers
  result = api_instance.filters_helpers_get
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FiltersApi->filters_helpers_get: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

**Object**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## filters_id_delete

> BaseResponse filters_id_delete

Delete a filter

Marks a filter as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FiltersApi.new

begin
  #Delete a filter
  result = api_instance.filters_id_delete
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FiltersApi->filters_id_delete: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## filters_id_get

> BaseResponse filters_id_get(id)

Get one filter

Returns data about a specific filter. Note that this also returns the condition lines of the filter.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FiltersApi.new
id = 56 # Integer | The ID of the filter

begin
  #Get one filter
  result = api_instance.filters_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FiltersApi->filters_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| The ID of the filter | 

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## filters_id_put

> filters_id_put(opts)

Update filter

Updates an existing filter.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FiltersApi.new
opts = {
  inline_object13: Pipedrive::InlineObject13.new # InlineObject13 | 
}

begin
  #Update filter
  api_instance.filters_id_put(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling FiltersApi->filters_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **inline_object13** | [**InlineObject13**](InlineObject13.md)|  | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined


## filters_post

> BaseResponse filters_post(opts)

Add a new filter

Adds a new filter, returns the ID upon success. Note that in the conditions JSON object only one first-level condition group is supported, and it must be glued with 'AND', and only two second level condition groups are supported of which one must be glued with 'AND' and the second with 'OR'. Other combinations do not work (yet) but the syntax supports introducing them in future. For more information on how to add a new filter, see <a href=\"https://pipedrive.readme.io/docs/adding-a-filter\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::FiltersApi.new
opts = {
  inline_object12: Pipedrive::InlineObject12.new # InlineObject12 | 
}

begin
  #Add a new filter
  result = api_instance.filters_post(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling FiltersApi->filters_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **inline_object12** | [**InlineObject12**](InlineObject12.md)|  | [optional] 

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

