# Pipedrive::GoalsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**goals_find_get**](GoalsApi.md#goals_find_get) | **GET** /goals/find | Find goals
[**goals_id_delete**](GoalsApi.md#goals_id_delete) | **DELETE** /goals/{id} | Delete existing goal
[**goals_id_put**](GoalsApi.md#goals_id_put) | **PUT** /goals/{id} | Update existing goal
[**goals_id_results_get**](GoalsApi.md#goals_id_results_get) | **GET** /goals/{id}/results | Get result of a goal
[**goals_post**](GoalsApi.md#goals_post) | **POST** /goals | Add a new goal



## goals_find_get

> goals_find_get(opts)

Find goals

Returns data about goals based on criteria. For searching, append `{searchField}={searchValue}` to the URL, where `searchField` can be any one of the lowest-level fields in dot-notation (e.g. `type.params.pipeline_id`; `title`). `searchValue` should be the value you are looking for on that field. Additionally, `is_active=<true|false>` can be provided to search for only active/inactive goals. When providing `period.start`, `period.end` must also be provided and vice versa.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::GoalsApi.new
opts = {
  type_name: 'type_name_example', # String | Type of the goal. If provided, everyone's goals will be returned.
  title: 'title_example', # String | Title of the goal.
  is_active: true, # Boolean | Whether goal is active or not.
  assignee_id: 56, # Integer | ID of the user who's goal to fetch. When omitted, only your goals will be returned.
  assignee_type: 'assignee_type_example', # String | Type of the goal's assignee. If provided, everyone's goals will be returned.
  expected_outcome_target: 3.4, # Float | Numeric value of the outcome. If provided, everyone's goals will be returned.
  expected_outcome_tracking_metric: 'expected_outcome_tracking_metric_example', # String | Tracking metric of the expected outcome of the goal. If provided, everyone's goals will be returned.
  expected_outcome_currency_id: 56, # Integer | Numeric ID of the goal's currency. Only applicable to goals with `expected_outcome.tracking_metric` with value `sum`. If provided, everyone's goals will be returned.
  type_params_pipeline_id: 56, # Integer | ID of the pipeline or `null` for all pipelines. If provided, everyone's goals will be returned.
  type_params_stage_id: 56, # Integer | ID of the stage. Applicable to only `deals_progressed` type of goals. If provided, everyone's goals will be returned.
  type_params_activity_type_id: 56, # Integer | ID of the activity type. Applicable to only `activities_completed` or `activities_added` types of goals. If provided, everyone's goals will be returned.
  period_start: Date.parse('2013-10-20'), # Date | Start date of the period for which to find goals. Date in format of YYYY-MM-DD. When `period.start` is provided, `period.end` must be provided too.
  period_end: Date.parse('2013-10-20') # Date | End date of the period for which to find goals. Date in format of YYYY-MM-DD.
}

begin
  #Find goals
  api_instance.goals_find_get(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling GoalsApi->goals_find_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **type_name** | **String**| Type of the goal. If provided, everyone&#39;s goals will be returned. | [optional] 
 **title** | **String**| Title of the goal. | [optional] 
 **is_active** | **Boolean**| Whether goal is active or not. | [optional] [default to true]
 **assignee_id** | **Integer**| ID of the user who&#39;s goal to fetch. When omitted, only your goals will be returned. | [optional] 
 **assignee_type** | **String**| Type of the goal&#39;s assignee. If provided, everyone&#39;s goals will be returned. | [optional] 
 **expected_outcome_target** | **Float**| Numeric value of the outcome. If provided, everyone&#39;s goals will be returned. | [optional] 
 **expected_outcome_tracking_metric** | **String**| Tracking metric of the expected outcome of the goal. If provided, everyone&#39;s goals will be returned. | [optional] 
 **expected_outcome_currency_id** | **Integer**| Numeric ID of the goal&#39;s currency. Only applicable to goals with &#x60;expected_outcome.tracking_metric&#x60; with value &#x60;sum&#x60;. If provided, everyone&#39;s goals will be returned. | [optional] 
 **type_params_pipeline_id** | **Integer**| ID of the pipeline or &#x60;null&#x60; for all pipelines. If provided, everyone&#39;s goals will be returned. | [optional] 
 **type_params_stage_id** | **Integer**| ID of the stage. Applicable to only &#x60;deals_progressed&#x60; type of goals. If provided, everyone&#39;s goals will be returned. | [optional] 
 **type_params_activity_type_id** | **Integer**| ID of the activity type. Applicable to only &#x60;activities_completed&#x60; or &#x60;activities_added&#x60; types of goals. If provided, everyone&#39;s goals will be returned. | [optional] 
 **period_start** | **Date**| Start date of the period for which to find goals. Date in format of YYYY-MM-DD. When &#x60;period.start&#x60; is provided, &#x60;period.end&#x60; must be provided too. | [optional] 
 **period_end** | **Date**| End date of the period for which to find goals. Date in format of YYYY-MM-DD. | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## goals_id_delete

> goals_id_delete(id)

Delete existing goal

Marks goal as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::GoalsApi.new
id = 'id_example' # String | ID of the goal to be deleted.

begin
  #Delete existing goal
  api_instance.goals_id_delete(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling GoalsApi->goals_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the goal to be deleted. | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## goals_id_put

> goals_id_put(id, opts)

Update existing goal

Updates existing goal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::GoalsApi.new
id = 'id_example' # String | ID of the goal to be updated.
opts = {
  title: 'title_example', # String | Title of the goal.
  assignee: nil, # Object | Who is this goal assigned to. It requires the following JSON structure: { \\\"id\\\": \\\"1\\\", \\\"type\\\": \\\"person\\\" }. `type` can be either `person`, `company` or `team`. ID of the assignee person, company or team.
  type: nil, # Object | Type of the goal. It requires the following JSON structure: { \\\"name\\\": \\\"deals_started\\\", \\\"params\\\": { \\\"pipeline_id\\\": 1 } }. Type can be one of: `deals_won`,`deals_progressed`,`activities_completed`,`activities_added` or `deals_started`. `params` can include `pipeline_id`, `stage_id` or `activity_type_id`. `stage_id` is related to only `deals_progressed` type of goals and `activity_type_id` to `activities_completed` or `activities_added` types of goals. To track goal in all pipelines set `pipeline_id` as `null`.
  expected_outcome: nil, # Object | Expected outcome of the goal. Expected outcome can be tracked either by `quantity` or by `sum`. It requires the following JSON structure: { \\\"target\\\": \\\"50\\\", \\\"tracking_metric\\\": \\\"quantity\\\" } or { \\\"target\\\": \\\"50\\\", \\\"tracking_metric\\\": \\\"sum\\\", \\\"currency_id\\\": 1 }. `currency_id` should only be added to `sum` type of goals.
  duration: nil, # Object | Date when the goal starts and ends. It requires the following JSON structure: { \\\"start\\\": \\\"2019-01-01\\\", \\\"end\\\": \\\"2022-12-31\\\" }. Date in format of YYYY-MM-DD.
  interval: 'interval_example' # String | Date when the goal starts and ends. It requires the following JSON structure: { \\\"start\\\": \\\"2019-01-01\\\", \\\"end\\\": \\\"2022-12-31\\\" }. Date in format of YYYY-MM-DD.
}

begin
  #Update existing goal
  api_instance.goals_id_put(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling GoalsApi->goals_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the goal to be updated. | 
 **title** | **String**| Title of the goal. | [optional] 
 **assignee** | [**Object**](Object.md)| Who is this goal assigned to. It requires the following JSON structure: { \\\&quot;id\\\&quot;: \\\&quot;1\\\&quot;, \\\&quot;type\\\&quot;: \\\&quot;person\\\&quot; }. &#x60;type&#x60; can be either &#x60;person&#x60;, &#x60;company&#x60; or &#x60;team&#x60;. ID of the assignee person, company or team. | [optional] 
 **type** | [**Object**](Object.md)| Type of the goal. It requires the following JSON structure: { \\\&quot;name\\\&quot;: \\\&quot;deals_started\\\&quot;, \\\&quot;params\\\&quot;: { \\\&quot;pipeline_id\\\&quot;: 1 } }. Type can be one of: &#x60;deals_won&#x60;,&#x60;deals_progressed&#x60;,&#x60;activities_completed&#x60;,&#x60;activities_added&#x60; or &#x60;deals_started&#x60;. &#x60;params&#x60; can include &#x60;pipeline_id&#x60;, &#x60;stage_id&#x60; or &#x60;activity_type_id&#x60;. &#x60;stage_id&#x60; is related to only &#x60;deals_progressed&#x60; type of goals and &#x60;activity_type_id&#x60; to &#x60;activities_completed&#x60; or &#x60;activities_added&#x60; types of goals. To track goal in all pipelines set &#x60;pipeline_id&#x60; as &#x60;null&#x60;. | [optional] 
 **expected_outcome** | [**Object**](Object.md)| Expected outcome of the goal. Expected outcome can be tracked either by &#x60;quantity&#x60; or by &#x60;sum&#x60;. It requires the following JSON structure: { \\\&quot;target\\\&quot;: \\\&quot;50\\\&quot;, \\\&quot;tracking_metric\\\&quot;: \\\&quot;quantity\\\&quot; } or { \\\&quot;target\\\&quot;: \\\&quot;50\\\&quot;, \\\&quot;tracking_metric\\\&quot;: \\\&quot;sum\\\&quot;, \\\&quot;currency_id\\\&quot;: 1 }. &#x60;currency_id&#x60; should only be added to &#x60;sum&#x60; type of goals. | [optional] 
 **duration** | [**Object**](Object.md)| Date when the goal starts and ends. It requires the following JSON structure: { \\\&quot;start\\\&quot;: \\\&quot;2019-01-01\\\&quot;, \\\&quot;end\\\&quot;: \\\&quot;2022-12-31\\\&quot; }. Date in format of YYYY-MM-DD. | [optional] 
 **interval** | **String**| Date when the goal starts and ends. It requires the following JSON structure: { \\\&quot;start\\\&quot;: \\\&quot;2019-01-01\\\&quot;, \\\&quot;end\\\&quot;: \\\&quot;2022-12-31\\\&quot; }. Date in format of YYYY-MM-DD. | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## goals_id_results_get

> goals_id_results_get(id, period_start, period_end)

Get result of a goal

Gets progress of a goal for specified period.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::GoalsApi.new
id = 'id_example' # String | ID of the goal that the results are looked for.
period_start = Date.parse('2013-10-20') # Date | Start date of the period for which to find progress of a goal. Date in format of YYYY-MM-DD.
period_end = Date.parse('2013-10-20') # Date | End date of the period for which to find progress of a goal. Date in format of YYYY-MM-DD.

begin
  #Get result of a goal
  api_instance.goals_id_results_get(id, period_start, period_end)
rescue Pipedrive::ApiError => e
  puts "Exception when calling GoalsApi->goals_id_results_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the goal that the results are looked for. | 
 **period_start** | **Date**| Start date of the period for which to find progress of a goal. Date in format of YYYY-MM-DD. | 
 **period_end** | **Date**| End date of the period for which to find progress of a goal. Date in format of YYYY-MM-DD. | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## goals_post

> goals_post

Add a new goal

Adds a new goal.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::GoalsApi.new

begin
  #Add a new goal
  api_instance.goals_post
rescue Pipedrive::ApiError => e
  puts "Exception when calling GoalsApi->goals_post: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined

