# Pipedrive::MailThreadsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**mailbox_mail_threads_get**](MailThreadsApi.md#mailbox_mail_threads_get) | **GET** /mailbox/mailThreads | Get mail threads
[**mailbox_mail_threads_id_delete**](MailThreadsApi.md#mailbox_mail_threads_id_delete) | **DELETE** /mailbox/mailThreads/{id} | Delete mail thread
[**mailbox_mail_threads_id_get**](MailThreadsApi.md#mailbox_mail_threads_id_get) | **GET** /mailbox/mailThreads/{id} | Get one mail thread
[**mailbox_mail_threads_id_mail_messages_get**](MailThreadsApi.md#mailbox_mail_threads_id_mail_messages_get) | **GET** /mailbox/mailThreads/{id}/mailMessages | Get all mail messages of mail thread
[**mailbox_mail_threads_id_put**](MailThreadsApi.md#mailbox_mail_threads_id_put) | **PUT** /mailbox/mailThreads/{id} | Update mail thread details



## mailbox_mail_threads_get

> MailThread mailbox_mail_threads_get(folder, opts)

Get mail threads

Returns mail threads in specified folder ordered by most recent message within.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::MailThreadsApi.new
folder = 'inbox' # String | Type of folder to fetch.
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #Get mail threads
  result = api_instance.mailbox_mail_threads_get(folder, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling MailThreadsApi->mailbox_mail_threads_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **folder** | **String**| Type of folder to fetch. | [default to &#39;inbox&#39;]
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**MailThread**](MailThread.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## mailbox_mail_threads_id_delete

> MailThreadDelete mailbox_mail_threads_id_delete(id)

Delete mail thread

Marks mail thread as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::MailThreadsApi.new
id = 56 # Integer | ID of the mail thread

begin
  #Delete mail thread
  result = api_instance.mailbox_mail_threads_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling MailThreadsApi->mailbox_mail_threads_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the mail thread | 

### Return type

[**MailThreadDelete**](MailThreadDelete.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## mailbox_mail_threads_id_get

> MailThreadOne mailbox_mail_threads_id_get(id)

Get one mail thread

Returns specific mail thread.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::MailThreadsApi.new
id = 56 # Integer | ID of the mail thread

begin
  #Get one mail thread
  result = api_instance.mailbox_mail_threads_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling MailThreadsApi->mailbox_mail_threads_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the mail thread | 

### Return type

[**MailThreadOne**](MailThreadOne.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## mailbox_mail_threads_id_mail_messages_get

> MailThreadMessages mailbox_mail_threads_id_mail_messages_get(id)

Get all mail messages of mail thread

Get mail messages inside specified mail thread.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::MailThreadsApi.new
id = 56 # Integer | ID of the mail thread

begin
  #Get all mail messages of mail thread
  result = api_instance.mailbox_mail_threads_id_mail_messages_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling MailThreadsApi->mailbox_mail_threads_id_mail_messages_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the mail thread | 

### Return type

[**MailThreadMessages**](MailThreadMessages.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## mailbox_mail_threads_id_put

> MailThreadPut mailbox_mail_threads_id_put(id, opts)

Update mail thread details

Updates the properties of a mail thread.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::MailThreadsApi.new
id = 56 # Integer | ID of the mail thread
opts = {
  deal_id: 56, # Integer | ID of the deal this thread is associated with
  shared_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | 
  read_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | 
  archived_flag: Pipedrive::NumberBoolean.new # NumberBoolean | 
}

begin
  #Update mail thread details
  result = api_instance.mailbox_mail_threads_id_put(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling MailThreadsApi->mailbox_mail_threads_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the mail thread | 
 **deal_id** | **Integer**| ID of the deal this thread is associated with | [optional] 
 **shared_flag** | [**NumberBoolean**](NumberBoolean.md)|  | [optional] 
 **read_flag** | [**NumberBoolean**](NumberBoolean.md)|  | [optional] 
 **archived_flag** | [**NumberBoolean**](NumberBoolean.md)|  | [optional] 

### Return type

[**MailThreadPut**](MailThreadPut.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json

