# Pipedrive::NotesApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**notes_get**](NotesApi.md#notes_get) | **GET** /notes | Get all notes
[**notes_id_delete**](NotesApi.md#notes_id_delete) | **DELETE** /notes/{id} | Delete a note
[**notes_id_get**](NotesApi.md#notes_id_get) | **GET** /notes/{id} | Get one note
[**notes_id_put**](NotesApi.md#notes_id_put) | **PUT** /notes/{id} | Update a note
[**notes_post**](NotesApi.md#notes_post) | **POST** /notes | Add a note



## notes_get

> GetNotes notes_get(opts)

Get all notes

Returns all notes.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::NotesApi.new
opts = {
  user_id: 56, # Integer | ID of the user whose notes to fetch. If omitted, notes by all users will be returned.
  deal_id: 56, # Integer | ID of the deal which notes to fetch. If omitted, notes about all deals with be returned.
  person_id: 56, # Integer | ID of the person whose notes to fetch. If omitted, notes about all persons with be returned.
  org_id: 56, # Integer | ID of the organization which notes to fetch. If omitted, notes about all organizations with be returned.
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  sort: 'sort_example', # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, content, add_time, update_time.
  start_date: Date.parse('2013-10-20'), # Date | Date in format of YYYY-MM-DD from which notes to fetch from.
  end_date: Date.parse('2013-10-20'), # Date | Date in format of YYYY-MM-DD until which notes to fetch to.
  pinned_to_deal_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | If set, then results are filtered by note to deal pinning state.
  pinned_to_organization_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | If set, then results are filtered by note to organization pinning state.
  pinned_to_person_flag: Pipedrive::NumberBoolean.new # NumberBoolean | If set, then results are filtered by note to person pinning state.
}

begin
  #Get all notes
  result = api_instance.notes_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling NotesApi->notes_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user_id** | **Integer**| ID of the user whose notes to fetch. If omitted, notes by all users will be returned. | [optional] 
 **deal_id** | **Integer**| ID of the deal which notes to fetch. If omitted, notes about all deals with be returned. | [optional] 
 **person_id** | **Integer**| ID of the person whose notes to fetch. If omitted, notes about all persons with be returned. | [optional] 
 **org_id** | **Integer**| ID of the organization which notes to fetch. If omitted, notes about all organizations with be returned. | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, content, add_time, update_time. | [optional] 
 **start_date** | **Date**| Date in format of YYYY-MM-DD from which notes to fetch from. | [optional] 
 **end_date** | **Date**| Date in format of YYYY-MM-DD until which notes to fetch to. | [optional] 
 **pinned_to_deal_flag** | [**NumberBoolean**](.md)| If set, then results are filtered by note to deal pinning state. | [optional] 
 **pinned_to_organization_flag** | [**NumberBoolean**](.md)| If set, then results are filtered by note to organization pinning state. | [optional] 
 **pinned_to_person_flag** | [**NumberBoolean**](.md)| If set, then results are filtered by note to person pinning state. | [optional] 

### Return type

[**GetNotes**](GetNotes.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## notes_id_delete

> DeleteNote notes_id_delete(id)

Delete a note

Deletes a specific note.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::NotesApi.new
id = 56 # Integer | ID of the note

begin
  #Delete a note
  result = api_instance.notes_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling NotesApi->notes_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the note | 

### Return type

[**DeleteNote**](DeleteNote.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## notes_id_get

> PostNote notes_id_get(id)

Get one note

Returns details about a specific note.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::NotesApi.new
id = 56 # Integer | ID of the note

begin
  #Get one note
  result = api_instance.notes_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling NotesApi->notes_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the note | 

### Return type

[**PostNote**](PostNote.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## notes_id_put

> PostNote notes_id_put(id, content, opts)

Update a note

Updates a note.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::NotesApi.new
id = 56 # Integer | ID of the note
content = 'content_example' # String | Content of the note in HTML format. Subject to sanitization on the back-end.
opts = {
  user_id: 56, # Integer | ID of the user who will be marked as the author of this note. Only an admin can change the author.
  deal_id: 56, # Integer | ID of the deal the note will be attached to.
  person_id: 56, # Integer | ID of the person this note will be attached to.
  org_id: 56, # Integer | ID of the organization this note will be attached to.
  add_time: 'add_time_example', # String | Optional creation date & time of the Note in UTC. Can be set in the past or in the future. Requires admin user API token. Format: YYYY-MM-DD HH:MM:SS
  pinned_to_deal_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | If set, then results are filtered by note to deal pinning state (deal_id is also required).
  pinned_to_organization_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | If set, then results are filtered by note to organization pinning state (org_id is also required).
  pinned_to_person_flag: Pipedrive::NumberBoolean.new # NumberBoolean | If set, then results are filtered by note to person pinning state (person_id is also required).
}

begin
  #Update a note
  result = api_instance.notes_id_put(id, content, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling NotesApi->notes_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the note | 
 **content** | **String**| Content of the note in HTML format. Subject to sanitization on the back-end. | 
 **user_id** | **Integer**| ID of the user who will be marked as the author of this note. Only an admin can change the author. | [optional] 
 **deal_id** | **Integer**| ID of the deal the note will be attached to. | [optional] 
 **person_id** | **Integer**| ID of the person this note will be attached to. | [optional] 
 **org_id** | **Integer**| ID of the organization this note will be attached to. | [optional] 
 **add_time** | **String**| Optional creation date &amp; time of the Note in UTC. Can be set in the past or in the future. Requires admin user API token. Format: YYYY-MM-DD HH:MM:SS | [optional] 
 **pinned_to_deal_flag** | [**NumberBoolean**](NumberBoolean.md)| If set, then results are filtered by note to deal pinning state (deal_id is also required). | [optional] 
 **pinned_to_organization_flag** | [**NumberBoolean**](NumberBoolean.md)| If set, then results are filtered by note to organization pinning state (org_id is also required). | [optional] 
 **pinned_to_person_flag** | [**NumberBoolean**](NumberBoolean.md)| If set, then results are filtered by note to person pinning state (person_id is also required). | [optional] 

### Return type

[**PostNote**](PostNote.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## notes_post

> PostNote notes_post(content, opts)

Add a note

Adds a new note.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::NotesApi.new
content = 'content_example' # String | Content of the note in HTML format. Subject to sanitization on the back-end.
opts = {
  user_id: 56, # Integer | ID of the user who will be marked as the author of this note. Only an admin can change the author.
  deal_id: 56, # Integer | ID of the deal the note will be attached to.
  person_id: 56, # Integer | ID of the person this note will be attached to.
  org_id: 56, # Integer | ID of the organization this note will be attached to.
  add_time: 'add_time_example', # String | Optional creation date & time of the Note in UTC. Can be set in the past or in the future. Requires admin user API token. Format: YYYY-MM-DD HH:MM:SS
  pinned_to_deal_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | If set, then results are filtered by note to deal pinning state (deal_id is also required).
  pinned_to_organization_flag: Pipedrive::NumberBoolean.new, # NumberBoolean | If set, then results are filtered by note to organization pinning state (org_id is also required).
  pinned_to_person_flag: Pipedrive::NumberBoolean.new # NumberBoolean | If set, then results are filtered by note to person pinning state (person_id is also required).
}

begin
  #Add a note
  result = api_instance.notes_post(content, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling NotesApi->notes_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **content** | **String**| Content of the note in HTML format. Subject to sanitization on the back-end. | 
 **user_id** | **Integer**| ID of the user who will be marked as the author of this note. Only an admin can change the author. | [optional] 
 **deal_id** | **Integer**| ID of the deal the note will be attached to. | [optional] 
 **person_id** | **Integer**| ID of the person this note will be attached to. | [optional] 
 **org_id** | **Integer**| ID of the organization this note will be attached to. | [optional] 
 **add_time** | **String**| Optional creation date &amp; time of the Note in UTC. Can be set in the past or in the future. Requires admin user API token. Format: YYYY-MM-DD HH:MM:SS | [optional] 
 **pinned_to_deal_flag** | [**NumberBoolean**](NumberBoolean.md)| If set, then results are filtered by note to deal pinning state (deal_id is also required). | [optional] 
 **pinned_to_organization_flag** | [**NumberBoolean**](NumberBoolean.md)| If set, then results are filtered by note to organization pinning state (org_id is also required). | [optional] 
 **pinned_to_person_flag** | [**NumberBoolean**](NumberBoolean.md)| If set, then results are filtered by note to person pinning state (person_id is also required). | [optional] 

### Return type

[**PostNote**](PostNote.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json

