# Pipedrive::OrganizationFieldsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**organization_fields_delete**](OrganizationFieldsApi.md#organization_fields_delete) | **DELETE** /organizationFields | Delete multiple organization fields in bulk
[**organization_fields_get**](OrganizationFieldsApi.md#organization_fields_get) | **GET** /organizationFields | Get all organization fields
[**organization_fields_id_delete**](OrganizationFieldsApi.md#organization_fields_id_delete) | **DELETE** /organizationFields/{id} | Delete an organization field
[**organization_fields_id_get**](OrganizationFieldsApi.md#organization_fields_id_get) | **GET** /organizationFields/{id} | Get one organization field
[**organization_fields_id_put**](OrganizationFieldsApi.md#organization_fields_id_put) | **PUT** /organizationFields/{id} | Update an organization field
[**organization_fields_post**](OrganizationFieldsApi.md#organization_fields_post) | **POST** /organizationFields | Add a new organization field



## organization_fields_delete

> organization_fields_delete(ids)

Delete multiple organization fields in bulk

Marks multiple fields as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::OrganizationFieldsApi.new
ids = 'ids_example' # String | Comma-separated field IDs to delete

begin
  #Delete multiple organization fields in bulk
  api_instance.organization_fields_delete(ids)
rescue Pipedrive::ApiError => e
  puts "Exception when calling OrganizationFieldsApi->organization_fields_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated field IDs to delete | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## organization_fields_get

> organization_fields_get

Get all organization fields

Returns data about all organization fields

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::OrganizationFieldsApi.new

begin
  #Get all organization fields
  api_instance.organization_fields_get
rescue Pipedrive::ApiError => e
  puts "Exception when calling OrganizationFieldsApi->organization_fields_get: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## organization_fields_id_delete

> organization_fields_id_delete(id)

Delete an organization field

Marks a field as deleted. For more information on how to delete a custom field, see <a href=\"https://pipedrive.readme.io/docs/deleting-a-custom-field\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::OrganizationFieldsApi.new
id = 56 # Integer | ID of the field

begin
  #Delete an organization field
  api_instance.organization_fields_id_delete(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling OrganizationFieldsApi->organization_fields_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the field | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## organization_fields_id_get

> organization_fields_id_get(id)

Get one organization field

Returns data about a specific organization field.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::OrganizationFieldsApi.new
id = 56 # Integer | ID of the field

begin
  #Get one organization field
  api_instance.organization_fields_id_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling OrganizationFieldsApi->organization_fields_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the field | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## organization_fields_id_put

> organization_fields_id_put(id, name, opts)

Update an organization field

Updates an organization field. See an example of updating custom fields’ values in <a href=\" https://pipedrive.readme.io/docs/updating-custom-field-value \" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::OrganizationFieldsApi.new
id = 56 # Integer | ID of the field
name = 'name_example' # String | Name of the field
opts = {
  options: 'options_example' # String | When field_type is either set or enum, possible options must be supplied as a JSON-encoded sequential array of objects. All active items must be supplied and already existing items must have their ID supplied. New items only require a label. Example: [{\\\"id\\\":123,\\\"label\\\":\\\"Existing Item\\\"},{\\\"label\\\":\\\"New Item\\\"}]
}

begin
  #Update an organization field
  api_instance.organization_fields_id_put(id, name, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling OrganizationFieldsApi->organization_fields_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the field | 
 **name** | **String**| Name of the field | 
 **options** | **String**| When field_type is either set or enum, possible options must be supplied as a JSON-encoded sequential array of objects. All active items must be supplied and already existing items must have their ID supplied. New items only require a label. Example: [{\\\&quot;id\\\&quot;:123,\\\&quot;label\\\&quot;:\\\&quot;Existing Item\\\&quot;},{\\\&quot;label\\\&quot;:\\\&quot;New Item\\\&quot;}] | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## organization_fields_post

> organization_fields_post

Add a new organization field

Adds a new organization field. For more information on adding a new custom field, see <a href=\"https://pipedrive.readme.io/docs/adding-a-new-custom-field\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::OrganizationFieldsApi.new

begin
  #Add a new organization field
  api_instance.organization_fields_post
rescue Pipedrive::ApiError => e
  puts "Exception when calling OrganizationFieldsApi->organization_fields_post: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined

