# Pipedrive::PersonsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**persons_delete**](PersonsApi.md#persons_delete) | **DELETE** /persons | Delete multiple persons in bulk
[**persons_find_get**](PersonsApi.md#persons_find_get) | **GET** /persons/find | Find persons by name
[**persons_get**](PersonsApi.md#persons_get) | **GET** /persons | Get all persons
[**persons_id_activities_get**](PersonsApi.md#persons_id_activities_get) | **GET** /persons/{id}/activities | List activities associated with a person
[**persons_id_deals_get**](PersonsApi.md#persons_id_deals_get) | **GET** /persons/{id}/deals | List deals associated with a person
[**persons_id_delete**](PersonsApi.md#persons_id_delete) | **DELETE** /persons/{id} | Delete a person
[**persons_id_files_get**](PersonsApi.md#persons_id_files_get) | **GET** /persons/{id}/files | List files attached to a person
[**persons_id_flow_get**](PersonsApi.md#persons_id_flow_get) | **GET** /persons/{id}/flow | List updates about a person
[**persons_id_followers_follower_id_delete**](PersonsApi.md#persons_id_followers_follower_id_delete) | **DELETE** /persons/{id}/followers/{follower_id} | Deletes a follower from a person.
[**persons_id_followers_get**](PersonsApi.md#persons_id_followers_get) | **GET** /persons/{id}/followers | List followers of a person
[**persons_id_followers_post**](PersonsApi.md#persons_id_followers_post) | **POST** /persons/{id}/followers | Add a follower to a person
[**persons_id_get**](PersonsApi.md#persons_id_get) | **GET** /persons/{id} | Get details of a person
[**persons_id_mail_messages_get**](PersonsApi.md#persons_id_mail_messages_get) | **GET** /persons/{id}/mailMessages | List mail messages associated with a person
[**persons_id_merge_put**](PersonsApi.md#persons_id_merge_put) | **PUT** /persons/{id}/merge | Merge two persons
[**persons_id_permitted_users_get**](PersonsApi.md#persons_id_permitted_users_get) | **GET** /persons/{id}/permittedUsers | List permitted users
[**persons_id_picture_delete**](PersonsApi.md#persons_id_picture_delete) | **DELETE** /persons/{id}/picture | Delete person picture
[**persons_id_picture_post**](PersonsApi.md#persons_id_picture_post) | **POST** /persons/{id}/picture | Add person picture
[**persons_id_products_get**](PersonsApi.md#persons_id_products_get) | **GET** /persons/{id}/products | List products associated with a person
[**persons_id_put**](PersonsApi.md#persons_id_put) | **PUT** /persons/{id} | Update a person
[**persons_post**](PersonsApi.md#persons_post) | **POST** /persons | Add a person
[**persons_search_get**](PersonsApi.md#persons_search_get) | **GET** /persons/search | Search persons



## persons_delete

> persons_delete(opts)

Delete multiple persons in bulk

Marks multiple persons as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
opts = {
  ids: 'ids_example' # String | Comma-separated IDs that will be deleted
}

begin
  #Delete multiple persons in bulk
  api_instance.persons_delete(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated IDs that will be deleted | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_find_get

> persons_find_get(term, opts)

Find persons by name

<strong>This endpoint is deprecated. Please use <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/Persons/get_persons_search\">/v1/persons/search</a> or <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/ItemSearch/get_itemSearch\">/v1/itemSearch</a> instead</strong>. <br> Searches all persons by their name.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
term = 'term_example' # String | Search term to look for
opts = {
  org_id: 56, # Integer | ID of the organization person is associated with.
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  search_by_email: Pipedrive::NumberBoolean.new # NumberBoolean | When enabled, term will only be matched against email addresses of people. Default: false
}

begin
  #Find persons by name
  api_instance.persons_find_get(term, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_find_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| Search term to look for | 
 **org_id** | **Integer**| ID of the organization person is associated with. | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **search_by_email** | [**NumberBoolean**](.md)| When enabled, term will only be matched against email addresses of people. Default: false | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_get

> persons_get(opts)

Get all persons

Returns all persons

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
opts = {
  user_id: 56, # Integer | If supplied, only persons owned by the given user will be returned.
  filter_id: 56, # Integer | ID of the filter to use.
  first_char: 'first_char_example', # String | If supplied, only persons whose name starts with the specified letter will be returned (case insensitive).
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  sort: 'sort_example' # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys).
}

begin
  #Get all persons
  api_instance.persons_get(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user_id** | **Integer**| If supplied, only persons owned by the given user will be returned. | [optional] 
 **filter_id** | **Integer**| ID of the filter to use. | [optional] 
 **first_char** | **String**| If supplied, only persons whose name starts with the specified letter will be returned (case insensitive). | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_activities_get

> persons_id_activities_get(id, opts)

List activities associated with a person

Lists activities associated with a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  done: Pipedrive::NumberBoolean.new, # NumberBoolean | Whether the activity is done or not. 0 = Not done, 1 = Done. If omitted returns both Done and Not done activities.
  exclude: 'exclude_example' # String | A comma-separated string of activity IDs to exclude from result
}

begin
  #List activities associated with a person
  api_instance.persons_id_activities_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_activities_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **done** | [**NumberBoolean**](.md)| Whether the activity is done or not. 0 &#x3D; Not done, 1 &#x3D; Done. If omitted returns both Done and Not done activities. | [optional] 
 **exclude** | **String**| A comma-separated string of activity IDs to exclude from result | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_deals_get

> persons_id_deals_get(id, opts)

List deals associated with a person

Lists deals associated with a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  status: 'all_not_deleted', # String | Only fetch deals with specific status. If omitted, all not deleted deals are fetched.
  sort: 'sort_example' # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys).
}

begin
  #List deals associated with a person
  api_instance.persons_id_deals_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_deals_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **status** | **String**| Only fetch deals with specific status. If omitted, all not deleted deals are fetched. | [optional] [default to &#39;all_not_deleted&#39;]
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_delete

> persons_id_delete(id)

Delete a person

Marks a person as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person

begin
  #Delete a person
  api_instance.persons_id_delete(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_files_get

> persons_id_files_get(id, opts)

List files attached to a person

Lists files associated with a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  include_deleted_files: Pipedrive::NumberBoolean.new, # NumberBoolean | When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work.
  sort: 'sort_example' # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment.
}

begin
  #List files attached to a person
  api_instance.persons_id_files_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_files_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **include_deleted_files** | [**NumberBoolean**](.md)| When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work. | [optional] 
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment. | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_flow_get

> persons_id_flow_get(id, opts)

List updates about a person

Lists updates about a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  all_changes: 'all_changes_example', # String | Whether to show custom field updates or not. 1 = Include custom field changes. If omitted returns changes without custom field updates.
  items: 'items_example' # String | A comma-separated string for filtering out item specific updates. (Possible values - activity, plannedActivity, note, file, change, deal, follower, participant, mailMessage, mailMessageWithAttachment, invoice, activityFile, document)
}

begin
  #List updates about a person
  api_instance.persons_id_flow_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_flow_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **all_changes** | **String**| Whether to show custom field updates or not. 1 &#x3D; Include custom field changes. If omitted returns changes without custom field updates. | [optional] 
 **items** | **String**| A comma-separated string for filtering out item specific updates. (Possible values - activity, plannedActivity, note, file, change, deal, follower, participant, mailMessage, mailMessageWithAttachment, invoice, activityFile, document) | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_followers_follower_id_delete

> persons_id_followers_follower_id_delete(id, follower_id)

Deletes a follower from a person.

Delete a follower from a person

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
follower_id = 56 # Integer | ID of the follower

begin
  #Deletes a follower from a person.
  api_instance.persons_id_followers_follower_id_delete(id, follower_id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_followers_follower_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **follower_id** | **Integer**| ID of the follower | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_followers_get

> persons_id_followers_get(id)

List followers of a person

Lists the followers of a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person

begin
  #List followers of a person
  api_instance.persons_id_followers_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_followers_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_followers_post

> persons_id_followers_post(id, user_id)

Add a follower to a person

Adds a follower to a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
user_id = 56 # Integer | ID of the user

begin
  #Add a follower to a person
  api_instance.persons_id_followers_post(id, user_id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_followers_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **user_id** | **Integer**| ID of the user | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## persons_id_get

> persons_id_get(id)

Get details of a person

Returns details of a person. Note that this also returns some additional fields which are not present when asking for all persons. Also note that custom fields appear as long hashes in the resulting data. These hashes can be mapped against the 'key' value of personFields.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person

begin
  #Get details of a person
  api_instance.persons_id_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_mail_messages_get

> persons_id_mail_messages_get(id, opts)

List mail messages associated with a person

Lists mail messages associated with a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List mail messages associated with a person
  api_instance.persons_id_mail_messages_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_mail_messages_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_merge_put

> persons_id_merge_put(id, merge_with_id)

Merge two persons

Merges a person with another person. For more information on how to merge two persons, see <a href=\"https://pipedrive.readme.io/docs/merging-two-persons\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
merge_with_id = 56 # Integer | The ID of the Person that will not be overwritten. This Person’s data will be prioritized in case of conflict with the other Person.

begin
  #Merge two persons
  api_instance.persons_id_merge_put(id, merge_with_id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_merge_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **merge_with_id** | **Integer**| The ID of the Person that will not be overwritten. This Person’s data will be prioritized in case of conflict with the other Person. | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## persons_id_permitted_users_get

> persons_id_permitted_users_get(id)

List permitted users

List users permitted to access a person

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person

begin
  #List permitted users
  api_instance.persons_id_permitted_users_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_permitted_users_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_picture_delete

> persons_id_picture_delete(id)

Delete person picture

Delete person picture

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person

begin
  #Delete person picture
  api_instance.persons_id_picture_delete(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_picture_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_picture_post

> persons_id_picture_post(id, file, opts)

Add person picture

Add a picture to a person. If a picture is already set, the old picture will be replaced. Added image (or the cropping parameters supplied with the request) should have an equal width and height and should be at least 128 pixels. GIF, JPG and PNG are accepted. All added images will be resized to 128 and 512 pixel wide squares.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
file = File.new('/path/to/file') # File | One image supplied in the multipart/form-data encoding.
opts = {
  crop_x: 56, # Integer | X coordinate to where start cropping form (in pixels)
  crop_y: 56, # Integer | Y coordinate to where start cropping form (in pixels)
  crop_width: 56, # Integer | Width of cropping area (in pixels)
  crop_height: 56 # Integer | Height of cropping area (in pixels)
}

begin
  #Add person picture
  api_instance.persons_id_picture_post(id, file, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_picture_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **file** | **File**| One image supplied in the multipart/form-data encoding. | 
 **crop_x** | **Integer**| X coordinate to where start cropping form (in pixels) | [optional] 
 **crop_y** | **Integer**| Y coordinate to where start cropping form (in pixels) | [optional] 
 **crop_width** | **Integer**| Width of cropping area (in pixels) | [optional] 
 **crop_height** | **Integer**| Height of cropping area (in pixels) | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: multipart/form-data
- **Accept**: Not defined


## persons_id_products_get

> persons_id_products_get(id, opts)

List products associated with a person

Lists products associated with a person.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List products associated with a person
  api_instance.persons_id_products_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_products_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## persons_id_put

> persons_id_put(id, opts)

Update a person

Updates the properties of a person. For more information on how to update a person, see <a href=\"https://pipedrive.readme.io/docs/updating-a-person\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
id = 56 # Integer | ID of a person
opts = {
  basic_person: Pipedrive::BasicPerson.new # BasicPerson | 
}

begin
  #Update a person
  api_instance.persons_id_put(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of a person | 
 **basic_person** | [**BasicPerson**](BasicPerson.md)|  | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined


## persons_post

> persons_post(opts)

Add a person

Adds a new person. Note that you can supply additional custom fields along with the request that are not described here. These custom fields are different for each Pipedrive account and can be recognized by long hashes as keys. To determine which custom fields exists, fetch the personFields and look for 'key' values.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
opts = {
  new_person: Pipedrive::NewPerson.new # NewPerson | 
}

begin
  #Add a person
  api_instance.persons_post(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **new_person** | [**NewPerson**](NewPerson.md)|  | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined


## persons_search_get

> BaseResponse persons_search_get(term, opts)

Search persons

Searches all Persons by name, email, phone, notes and/or custom fields. This endpoint is a wrapper of <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/ItemSearch/get_itemSearch\">/v1/itemSearch</a> with a narrower OAuth scope. Found Persons can be filtered by Organization ID.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PersonsApi.new
term = 'term_example' # String | The search term to look for. Minimum 2 characters (or 1 if using exact_match).
opts = {
  fields: 'fields_example', # String | A comma-separated string array. The fields to perform the search from. Defaults to all of them.
  exact_match: true, # Boolean | When enabled, only full exact matches against the given term are returned. It is <b>not</b> case sensitive.
  organization_id: 56, # Integer | Will filter Deals by the provided Organization ID. The upper limit of found Deals associated with the Organization is 2000.
  include_fields: 'include_fields_example', # String | Supports including optional fields in the results which are not provided by default.
  start: 0, # Integer | Pagination start. Note that the pagination is based on main results and does not include related items when using search_for_related_items parameter.
  limit: 56 # Integer | Items shown per page
}

begin
  #Search persons
  result = api_instance.persons_search_get(term, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PersonsApi->persons_search_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| The search term to look for. Minimum 2 characters (or 1 if using exact_match). | 
 **fields** | **String**| A comma-separated string array. The fields to perform the search from. Defaults to all of them. | [optional] 
 **exact_match** | **Boolean**| When enabled, only full exact matches against the given term are returned. It is &lt;b&gt;not&lt;/b&gt; case sensitive. | [optional] 
 **organization_id** | **Integer**| Will filter Deals by the provided Organization ID. The upper limit of found Deals associated with the Organization is 2000. | [optional] 
 **include_fields** | **String**| Supports including optional fields in the results which are not provided by default. | [optional] 
 **start** | **Integer**| Pagination start. Note that the pagination is based on main results and does not include related items when using search_for_related_items parameter. | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

