# Pipedrive::PipelinesApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**pipelines_get**](PipelinesApi.md#pipelines_get) | **GET** /pipelines | Get all pipelines
[**pipelines_id_conversion_statistics_get**](PipelinesApi.md#pipelines_id_conversion_statistics_get) | **GET** /pipelines/{id}/conversion_statistics | Get deals conversion rates in pipeline
[**pipelines_id_deals_get**](PipelinesApi.md#pipelines_id_deals_get) | **GET** /pipelines/{id}/deals | Get deals in a pipeline
[**pipelines_id_delete**](PipelinesApi.md#pipelines_id_delete) | **DELETE** /pipelines/{id} | Delete a pipeline
[**pipelines_id_get**](PipelinesApi.md#pipelines_id_get) | **GET** /pipelines/{id} | Get one pipeline
[**pipelines_id_movement_statistics_get**](PipelinesApi.md#pipelines_id_movement_statistics_get) | **GET** /pipelines/{id}/movement_statistics | Get deals movements in pipeline
[**pipelines_id_put**](PipelinesApi.md#pipelines_id_put) | **PUT** /pipelines/{id} | Edit a pipeline
[**pipelines_post**](PipelinesApi.md#pipelines_post) | **POST** /pipelines | Add a new pipeline



## pipelines_get

> GetAllPipelines pipelines_get

Get all pipelines

Returns data about all pipelines

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new

begin
  #Get all pipelines
  result = api_instance.pipelines_get
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_get: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**GetAllPipelines**](GetAllPipelines.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## pipelines_id_conversion_statistics_get

> GetDealsConversionRatesInPipeline pipelines_id_conversion_statistics_get(id, start_date, end_date, opts)

Get deals conversion rates in pipeline

Returns all stage-to-stage conversion and pipeline-to-close rates for given time period.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new
id = 56 # Integer | ID of the pipeline
start_date = Date.parse('2013-10-20') # Date | Start of the period. Date in format of YYYY-MM-DD.
end_date = Date.parse('2013-10-20') # Date | End of the period. Date in format of YYYY-MM-DD.
opts = {
  user_id: 56 # Integer | ID of the user who's pipeline metrics statistics to fetch. If omitted, the authorized user will be used.
}

begin
  #Get deals conversion rates in pipeline
  result = api_instance.pipelines_id_conversion_statistics_get(id, start_date, end_date, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_id_conversion_statistics_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the pipeline | 
 **start_date** | **Date**| Start of the period. Date in format of YYYY-MM-DD. | 
 **end_date** | **Date**| End of the period. Date in format of YYYY-MM-DD. | 
 **user_id** | **Integer**| ID of the user who&#39;s pipeline metrics statistics to fetch. If omitted, the authorized user will be used. | [optional] 

### Return type

[**GetDealsConversionRatesInPipeline**](GetDealsConversionRatesInPipeline.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## pipelines_id_deals_get

> GetStageDeals pipelines_id_deals_get(id, opts)

Get deals in a pipeline

Lists deals in a specific pipeline across all its stages

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new
id = 56 # Integer | ID of the pipeline
opts = {
  filter_id: 56, # Integer | If supplied, only deals matching the given filter will be returned.
  user_id: 56, # Integer | If supplied, filter_id will not be considered and only deals owned by the given user will be returned. If omitted, deals owned by the authorized user will be returned.
  everyone: Pipedrive::NumberBoolean.new, # NumberBoolean | If supplied, filter_id and user_id will not be considered – instead, deals owned by everyone will be returned.
  stage_id: 56, # Integer | If supplied, only deals within the given stage will be returned.
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  get_summary: Pipedrive::NumberBoolean.new, # NumberBoolean | Whether to include summary of the pipeline in the additional_data or not.
  totals_convert_currency: 'totals_convert_currency_example' # String | 3-letter currency code of any of the supported currencies. When supplied, per_stages_converted is returned inside deals_summary inside additional_data which contains the currency-converted total amounts in the given currency per each stage. You may also set this parameter to 'default_currency' in which case users default currency is used. Only works when get_summary parameter flag is enabled.
}

begin
  #Get deals in a pipeline
  result = api_instance.pipelines_id_deals_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_id_deals_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the pipeline | 
 **filter_id** | **Integer**| If supplied, only deals matching the given filter will be returned. | [optional] 
 **user_id** | **Integer**| If supplied, filter_id will not be considered and only deals owned by the given user will be returned. If omitted, deals owned by the authorized user will be returned. | [optional] 
 **everyone** | [**NumberBoolean**](.md)| If supplied, filter_id and user_id will not be considered – instead, deals owned by everyone will be returned. | [optional] 
 **stage_id** | **Integer**| If supplied, only deals within the given stage will be returned. | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **get_summary** | [**NumberBoolean**](.md)| Whether to include summary of the pipeline in the additional_data or not. | [optional] 
 **totals_convert_currency** | **String**| 3-letter currency code of any of the supported currencies. When supplied, per_stages_converted is returned inside deals_summary inside additional_data which contains the currency-converted total amounts in the given currency per each stage. You may also set this parameter to &#39;default_currency&#39; in which case users default currency is used. Only works when get_summary parameter flag is enabled. | [optional] 

### Return type

[**GetStageDeals**](GetStageDeals.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## pipelines_id_delete

> InlineResponse2009 pipelines_id_delete(id)

Delete a pipeline

Marks a pipeline as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new
id = 56 # Integer | ID of the pipeline

begin
  #Delete a pipeline
  result = api_instance.pipelines_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the pipeline | 

### Return type

[**InlineResponse2009**](InlineResponse2009.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## pipelines_id_get

> GetOnePipeline pipelines_id_get(id, opts)

Get one pipeline

Returns data about a specific pipeline. Also returns the summary of the deals in this pipeline across its stages.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new
id = 56 # Integer | ID of the pipeline
opts = {
  totals_convert_currency: 'totals_convert_currency_example' # String | 3-letter currency code of any of the supported currencies. When supplied, per_stages_converted is returned in deals_summary which contains the currency-converted total amounts in the given currency per each stage. You may also set this parameter to 'default_currency' in which case users default currency is used.
}

begin
  #Get one pipeline
  result = api_instance.pipelines_id_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the pipeline | 
 **totals_convert_currency** | **String**| 3-letter currency code of any of the supported currencies. When supplied, per_stages_converted is returned in deals_summary which contains the currency-converted total amounts in the given currency per each stage. You may also set this parameter to &#39;default_currency&#39; in which case users default currency is used. | [optional] 

### Return type

[**GetOnePipeline**](GetOnePipeline.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## pipelines_id_movement_statistics_get

> GetDealsMovementsInPipeline pipelines_id_movement_statistics_get(id, start_date, end_date, opts)

Get deals movements in pipeline

Returns statistics for deals movements for given time period.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new
id = 56 # Integer | ID of the pipeline
start_date = Date.parse('2013-10-20') # Date | Start of the period. Date in format of YYYY-MM-DD.
end_date = Date.parse('2013-10-20') # Date | End of the period. Date in format of YYYY-MM-DD.
opts = {
  user_id: 56 # Integer | ID of the user who's pipeline statistics to fetch. If omitted, the authorized user will be used.
}

begin
  #Get deals movements in pipeline
  result = api_instance.pipelines_id_movement_statistics_get(id, start_date, end_date, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_id_movement_statistics_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the pipeline | 
 **start_date** | **Date**| Start of the period. Date in format of YYYY-MM-DD. | 
 **end_date** | **Date**| End of the period. Date in format of YYYY-MM-DD. | 
 **user_id** | **Integer**| ID of the user who&#39;s pipeline statistics to fetch. If omitted, the authorized user will be used. | [optional] 

### Return type

[**GetDealsMovementsInPipeline**](GetDealsMovementsInPipeline.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## pipelines_id_put

> EditPipeline pipelines_id_put(id, opts)

Edit a pipeline

Updates pipeline properties

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new
id = 56 # Integer | ID of the pipeline
opts = {
  name: 'name_example', # String | The name of the Pipeline
  deal_probability: Pipedrive::NumberBoolean.new, # NumberBoolean | 
  order_nr: 56, # Integer | Defines the order of Pipelines. First order (order_nr=0) is the default Pipeline.
  active: Pipedrive::NumberBoolean.new # NumberBoolean | 
}

begin
  #Edit a pipeline
  result = api_instance.pipelines_id_put(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the pipeline | 
 **name** | **String**| The name of the Pipeline | [optional] 
 **deal_probability** | [**NumberBoolean**](NumberBoolean.md)|  | [optional] 
 **order_nr** | **Integer**| Defines the order of Pipelines. First order (order_nr&#x3D;0) is the default Pipeline. | [optional] 
 **active** | [**NumberBoolean**](NumberBoolean.md)|  | [optional] 

### Return type

[**EditPipeline**](EditPipeline.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## pipelines_post

> AddNewPipeline pipelines_post(opts)

Add a new pipeline

Adds a new pipeline

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::PipelinesApi.new
opts = {
  name: 'name_example', # String | The name of the Pipeline
  deal_probability: Pipedrive::NumberBoolean.new, # NumberBoolean | 
  order_nr: 56, # Integer | Defines the order of Pipelines. First order (order_nr=0) is the default Pipeline.
  active: Pipedrive::NumberBoolean.new # NumberBoolean | 
}

begin
  #Add a new pipeline
  result = api_instance.pipelines_post(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling PipelinesApi->pipelines_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| The name of the Pipeline | [optional] 
 **deal_probability** | [**NumberBoolean**](NumberBoolean.md)|  | [optional] 
 **order_nr** | **Integer**| Defines the order of Pipelines. First order (order_nr&#x3D;0) is the default Pipeline. | [optional] 
 **active** | [**NumberBoolean**](NumberBoolean.md)|  | [optional] 

### Return type

[**AddNewPipeline**](AddNewPipeline.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json

