# Pipedrive::ProductFieldsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**product_fields_delete**](ProductFieldsApi.md#product_fields_delete) | **DELETE** /productFields | Delete multiple product fields in bulk
[**product_fields_get**](ProductFieldsApi.md#product_fields_get) | **GET** /productFields | Get all product fields
[**product_fields_id_delete**](ProductFieldsApi.md#product_fields_id_delete) | **DELETE** /productFields/{id} | Delete a product field
[**product_fields_id_get**](ProductFieldsApi.md#product_fields_id_get) | **GET** /productFields/{id} | Get one product field
[**product_fields_id_put**](ProductFieldsApi.md#product_fields_id_put) | **PUT** /productFields/{id} | Update a product field
[**product_fields_post**](ProductFieldsApi.md#product_fields_post) | **POST** /productFields | Add a new product field



## product_fields_delete

> DeleteMultipleProductFieldsResponse product_fields_delete(ids)

Delete multiple product fields in bulk

Marks multiple fields as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductFieldsApi.new
ids = 'ids_example' # String | Comma-separated field IDs to delete

begin
  #Delete multiple product fields in bulk
  result = api_instance.product_fields_delete(ids)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductFieldsApi->product_fields_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated field IDs to delete | 

### Return type

[**DeleteMultipleProductFieldsResponse**](DeleteMultipleProductFieldsResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## product_fields_get

> GetAllProductFieldsResponse product_fields_get

Get all product fields

Returns data about all product fields

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductFieldsApi.new

begin
  #Get all product fields
  result = api_instance.product_fields_get
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductFieldsApi->product_fields_get: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**GetAllProductFieldsResponse**](GetAllProductFieldsResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## product_fields_id_delete

> DeleteProductFieldResponse product_fields_id_delete(id)

Delete a product field

Marks a field as deleted. For more information on how to delete a custom field, see <a href=\"https://pipedrive.readme.io/docs/deleting-a-custom-field\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductFieldsApi.new
id = 56 # Integer | ID of the Product Field

begin
  #Delete a product field
  result = api_instance.product_fields_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductFieldsApi->product_fields_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the Product Field | 

### Return type

[**DeleteProductFieldResponse**](DeleteProductFieldResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## product_fields_id_get

> GetProductFieldResponse product_fields_id_get(id)

Get one product field

Returns data about a specific product field.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductFieldsApi.new
id = 56 # Integer | ID of the Product Field

begin
  #Get one product field
  result = api_instance.product_fields_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductFieldsApi->product_fields_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the Product Field | 

### Return type

[**GetProductFieldResponse**](GetProductFieldResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## product_fields_id_put

> GetProductFieldResponse product_fields_id_put(id, opts)

Update a product field

Updates a product field. See an example of updating custom fields’ values in <a href=\" https://pipedrive.readme.io/docs/updating-custom-field-value \" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductFieldsApi.new
id = 56 # Integer | ID of the Product Field
opts = {
  basic_product_field: Pipedrive::BasicProductField.new # BasicProductField | 
}

begin
  #Update a product field
  result = api_instance.product_fields_id_put(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductFieldsApi->product_fields_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the Product Field | 
 **basic_product_field** | [**BasicProductField**](BasicProductField.md)|  | [optional] 

### Return type

[**GetProductFieldResponse**](GetProductFieldResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## product_fields_post

> GetProductFieldResponse product_fields_post(opts)

Add a new product field

Adds a new product field. For more information on adding a new custom field, see <a href=\"https://pipedrive.readme.io/docs/adding-a-new-custom-field\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductFieldsApi.new
opts = {
  new_product_field: Pipedrive::NewProductField.new # NewProductField | 
}

begin
  #Add a new product field
  result = api_instance.product_fields_post(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductFieldsApi->product_fields_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **new_product_field** | [**NewProductField**](NewProductField.md)|  | [optional] 

### Return type

[**GetProductFieldResponse**](GetProductFieldResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

