# Pipedrive::ProductsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**products_find_get**](ProductsApi.md#products_find_get) | **GET** /products/find | Find products by name
[**products_get**](ProductsApi.md#products_get) | **GET** /products | Get all products
[**products_id_deals_get**](ProductsApi.md#products_id_deals_get) | **GET** /products/{id}/deals | Get deals where a product is attached to
[**products_id_delete**](ProductsApi.md#products_id_delete) | **DELETE** /products/{id} | Delete a product
[**products_id_files_get**](ProductsApi.md#products_id_files_get) | **GET** /products/{id}/files | List files attached to a product
[**products_id_followers_follower_id_delete**](ProductsApi.md#products_id_followers_follower_id_delete) | **DELETE** /products/{id}/followers/{follower_id} | Delete a follower from a product
[**products_id_followers_get**](ProductsApi.md#products_id_followers_get) | **GET** /products/{id}/followers | List followers of a product
[**products_id_followers_post**](ProductsApi.md#products_id_followers_post) | **POST** /products/{id}/followers | Add a follower to a product
[**products_id_get**](ProductsApi.md#products_id_get) | **GET** /products/{id} | Get one product
[**products_id_permitted_users_get**](ProductsApi.md#products_id_permitted_users_get) | **GET** /products/{id}/permittedUsers | List permitted users
[**products_id_put**](ProductsApi.md#products_id_put) | **PUT** /products/{id} | Update a product
[**products_post**](ProductsApi.md#products_post) | **POST** /products | Add a product
[**products_search_get**](ProductsApi.md#products_search_get) | **GET** /products/search | Search products



## products_find_get

> FindProductsByNameResponse products_find_get(term, opts)

Find products by name

<strong>This endpoint is deprecated. Please use <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/Products/get_products_search\">/v1/products/search</a> or <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/ItemSearch/get_itemSearch\">/v1/itemSearch</a> instead</strong>. <br> Returns data about the products that were found. If currency was set in request, prices in that currency are served back.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
term = 'term_example' # String | Search term to look for, minimum 3 characters.
opts = {
  currency: 'currency_example', # String | Currency code in which prices should be returned in. If omitted, prices in user's default currency will be returned.
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #Find products by name
  result = api_instance.products_find_get(term, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_find_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| Search term to look for, minimum 3 characters. | 
 **currency** | **String**| Currency code in which prices should be returned in. If omitted, prices in user&#39;s default currency will be returned. | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**FindProductsByNameResponse**](FindProductsByNameResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## products_get

> Product products_get(opts)

Get all products

Returns data about all products.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
opts = {
  user_id: 56, # Integer | If supplied, only products owned by the given user will be returned.
  filter_id: 56, # Integer | ID of the filter to use
  first_char: 'first_char_example', # String | If supplied, only products whose name starts with the specified letter will be returned (case insensitive).
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #Get all products
  result = api_instance.products_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user_id** | **Integer**| If supplied, only products owned by the given user will be returned. | [optional] 
 **filter_id** | **Integer**| ID of the filter to use | [optional] 
 **first_char** | **String**| If supplied, only products whose name starts with the specified letter will be returned (case insensitive). | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**Product**](Product.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## products_id_deals_get

> BasicDeal products_id_deals_get(id, opts)

Get deals where a product is attached to

Returns data about deals that have a product attached to.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  status: 'all_not_deleted' # String | Only fetch deals with specific status. If omitted, all not deleted deals are fetched.
}

begin
  #Get deals where a product is attached to
  result = api_instance.products_id_deals_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_deals_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **status** | **String**| Only fetch deals with specific status. If omitted, all not deleted deals are fetched. | [optional] [default to &#39;all_not_deleted&#39;]

### Return type

[**BasicDeal**](BasicDeal.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## products_id_delete

> products_id_delete(id)

Delete a product

Marks a product as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product

begin
  #Delete a product
  api_instance.products_id_delete(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## products_id_files_get

> products_id_files_get(id, opts)

List files attached to a product

Lists files associated with a product.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product
opts = {
  start: 0, # Integer | Pagination start
  limit: 56, # Integer | Items shown per page
  include_deleted_files: Pipedrive::NumberBoolean.new, # NumberBoolean | When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work.
  sort: 'sort_example' # String | Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment.
}

begin
  #List files attached to a product
  api_instance.products_id_files_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_files_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 
 **include_deleted_files** | [**NumberBoolean**](.md)| When enabled, the list of files will also include deleted files. Please note that trying to download these files will not work. | [optional] 
 **sort** | **String**| Field names and sorting mode separated by a comma (field_name_1 ASC, field_name_2 DESC). Only first-level field keys are supported (no nested keys). Supported fields: id, user_id, deal_id, person_id, org_id, product_id, add_time, update_time, file_name, file_type, file_size, comment. | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## products_id_followers_follower_id_delete

> DeleteProductFollowerResponse products_id_followers_follower_id_delete(id, follower_id)

Delete a follower from a product

Deletes a follower from a product.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product
follower_id = 56 # Integer | ID of the follower

begin
  #Delete a follower from a product
  result = api_instance.products_id_followers_follower_id_delete(id, follower_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_followers_follower_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 
 **follower_id** | **Integer**| ID of the follower | 

### Return type

[**DeleteProductFollowerResponse**](DeleteProductFollowerResponse.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## products_id_followers_get

> UserIDs products_id_followers_get(id)

List followers of a product

Lists the followers of a Product

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product

begin
  #List followers of a product
  result = api_instance.products_id_followers_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_followers_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 

### Return type

[**UserIDs**](UserIDs.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## products_id_followers_post

> NewFollowerResponse products_id_followers_post(id, opts)

Add a follower to a product

Adds a follower to a product.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product
opts = {
  inline_object24: Pipedrive::InlineObject24.new # InlineObject24 | 
}

begin
  #Add a follower to a product
  result = api_instance.products_id_followers_post(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_followers_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 
 **inline_object24** | [**InlineObject24**](InlineObject24.md)|  | [optional] 

### Return type

[**NewFollowerResponse**](NewFollowerResponse.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## products_id_get

> products_id_get(id)

Get one product

Returns data about a specific product.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product

begin
  #Get one product
  api_instance.products_id_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## products_id_permitted_users_get

> UserIDs products_id_permitted_users_get(id)

List permitted users

Lists users permitted to access a product.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product

begin
  #List permitted users
  result = api_instance.products_id_permitted_users_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_permitted_users_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 

### Return type

[**UserIDs**](UserIDs.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## products_id_put

> Product products_id_put(id, opts)

Update a product

Updates product data.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
id = 56 # Integer | ID of the product
opts = {
  product: Pipedrive::Product.new # Product | 
}

begin
  #Update a product
  result = api_instance.products_id_put(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the product | 
 **product** | [**Product**](Product.md)|  | [optional] 

### Return type

[**Product**](Product.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## products_post

> products_post(opts)

Add a product

Adds a new product to the products inventory. For more information on how to add a product, see <a href=\"https://pipedrive.readme.io/docs/adding-a-product\" target=\"_blank\" rel=\"noopener noreferrer\">this tutorial</a>.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
opts = {
  unknown_base_type: Pipedrive::UNKNOWN_BASE_TYPE.new # UNKNOWN_BASE_TYPE | 
}

begin
  #Add a product
  api_instance.products_post(opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **unknown_base_type** | [**UNKNOWN_BASE_TYPE**](UNKNOWN_BASE_TYPE.md)|  | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined


## products_search_get

> BaseResponse products_search_get(term, opts)

Search products

Searches all Products by name, code and/or custom fields. This endpoint is a wrapper of <a href=\"https://developers.pipedrive.com/docs/api/v1/#!/ItemSearch/get_itemSearch\">/v1/itemSearch</a> with a narrower OAuth scope.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::ProductsApi.new
term = 'term_example' # String | The search term to look for. Minimum 2 characters (or 1 if using exact_match).
opts = {
  fields: 'fields_example', # String | A comma-separated string array. The fields to perform the search from. Defaults to all of them.
  exact_match: true, # Boolean | When enabled, only full exact matches against the given term are returned. It is <b>not</b> case sensitive.
  include_fields: 'include_fields_example', # String | Supports including optional fields in the results which are not provided by default.
  start: 0, # Integer | Pagination start. Note that the pagination is based on main results and does not include related items when using search_for_related_items parameter.
  limit: 56 # Integer | Items shown per page
}

begin
  #Search products
  result = api_instance.products_search_get(term, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling ProductsApi->products_search_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| The search term to look for. Minimum 2 characters (or 1 if using exact_match). | 
 **fields** | **String**| A comma-separated string array. The fields to perform the search from. Defaults to all of them. | [optional] 
 **exact_match** | **Boolean**| When enabled, only full exact matches against the given term are returned. It is &lt;b&gt;not&lt;/b&gt; case sensitive. | [optional] 
 **include_fields** | **String**| Supports including optional fields in the results which are not provided by default. | [optional] 
 **start** | **Integer**| Pagination start. Note that the pagination is based on main results and does not include related items when using search_for_related_items parameter. | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**BaseResponse**](BaseResponse.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

