# Pipedrive::RolesApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**roles_get**](RolesApi.md#roles_get) | **GET** /roles | Get all roles
[**roles_id_assignments_delete**](RolesApi.md#roles_id_assignments_delete) | **DELETE** /roles/{id}/assignments | Delete a role assignment
[**roles_id_assignments_get**](RolesApi.md#roles_id_assignments_get) | **GET** /roles/{id}/assignments | List role assignments
[**roles_id_assignments_post**](RolesApi.md#roles_id_assignments_post) | **POST** /roles/{id}/assignments | Add role assignment
[**roles_id_delete**](RolesApi.md#roles_id_delete) | **DELETE** /roles/{id} | Delete a role
[**roles_id_get**](RolesApi.md#roles_id_get) | **GET** /roles/{id} | Get one role
[**roles_id_put**](RolesApi.md#roles_id_put) | **PUT** /roles/{id} | Update role details
[**roles_id_roles_get**](RolesApi.md#roles_id_roles_get) | **GET** /roles/{id}/roles | List role sub-roles
[**roles_id_settings_get**](RolesApi.md#roles_id_settings_get) | **GET** /roles/{id}/settings | List role settings
[**roles_id_settings_post**](RolesApi.md#roles_id_settings_post) | **POST** /roles/{id}/settings | Add or update role setting
[**roles_post**](RolesApi.md#roles_post) | **POST** /roles | Add a role



## roles_get

> GetRoles roles_get(opts)

Get all roles

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #Get all roles
  result = api_instance.roles_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**GetRoles**](GetRoles.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## roles_id_assignments_delete

> DeleteRoleAssignment roles_id_assignments_delete(id, user_id)

Delete a role assignment

Delete assignment from a role

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role
user_id = 56 # Integer | ID of the user

begin
  #Delete a role assignment
  result = api_instance.roles_id_assignments_delete(id, user_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_assignments_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 
 **user_id** | **Integer**| ID of the user | 

### Return type

[**DeleteRoleAssignment**](DeleteRoleAssignment.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## roles_id_assignments_get

> GetRoleAssignments roles_id_assignments_get(id, opts)

List role assignments

List assignments for a role

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List role assignments
  result = api_instance.roles_id_assignments_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_assignments_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**GetRoleAssignments**](GetRoleAssignments.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## roles_id_assignments_post

> PostRoleAssignment roles_id_assignments_post(id, user_id)

Add role assignment

Add assignment for a role

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role
user_id = 56 # Integer | ID of the user

begin
  #Add role assignment
  result = api_instance.roles_id_assignments_post(id, user_id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_assignments_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 
 **user_id** | **Integer**| ID of the user | 

### Return type

[**PostRoleAssignment**](PostRoleAssignment.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## roles_id_delete

> DeleteRole roles_id_delete(id)

Delete a role

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role

begin
  #Delete a role
  result = api_instance.roles_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 

### Return type

[**DeleteRole**](DeleteRole.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## roles_id_get

> GetRole roles_id_get(id)

Get one role

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role

begin
  #Get one role
  result = api_instance.roles_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 

### Return type

[**GetRole**](GetRole.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## roles_id_put

> PutRole roles_id_put(id, opts)

Update role details

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role
opts = {
  parent_role_id: 56, # Integer | The ID of the parent Role
  name: 'name_example' # String | The name of the Role
}

begin
  #Update role details
  result = api_instance.roles_id_put(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 
 **parent_role_id** | **Integer**| The ID of the parent Role | [optional] 
 **name** | **String**| The name of the Role | [optional] 

### Return type

[**PutRole**](PutRole.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## roles_id_roles_get

> GetRoleSubroles roles_id_roles_get(id, opts)

List role sub-roles

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List role sub-roles
  result = api_instance.roles_id_roles_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_roles_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**GetRoleSubroles**](GetRoleSubroles.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## roles_id_settings_get

> GetRoleSettings roles_id_settings_get(id)

List role settings

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role

begin
  #List role settings
  result = api_instance.roles_id_settings_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_settings_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 

### Return type

[**GetRoleSettings**](GetRoleSettings.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## roles_id_settings_post

> PostRoleSettings roles_id_settings_post(id, setting_key, value)

Add or update role setting

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new
id = 56 # Integer | ID of the role
setting_key = 'setting_key_example' # String | 
value = Pipedrive::NumberBooleanDefault0.new # NumberBooleanDefault0 | Possible values for default_visibility settings: 0...1.

begin
  #Add or update role setting
  result = api_instance.roles_id_settings_post(id, setting_key, value)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_id_settings_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the role | 
 **setting_key** | **String**|  | 
 **value** | [**NumberBooleanDefault0**](NumberBooleanDefault0.md)| Possible values for default_visibility settings: 0...1. | 

### Return type

[**PostRoleSettings**](PostRoleSettings.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## roles_post

> PostRoles roles_post

Add a role

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::RolesApi.new

begin
  #Add a role
  result = api_instance.roles_post
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling RolesApi->roles_post: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**PostRoles**](PostRoles.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json

