# Pipedrive::StagesApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**stages_delete**](StagesApi.md#stages_delete) | **DELETE** /stages | Delete multiple stages in bulk
[**stages_get**](StagesApi.md#stages_get) | **GET** /stages | Get all stages
[**stages_id_deals_get**](StagesApi.md#stages_id_deals_get) | **GET** /stages/{id}/deals | Get deals in a stage
[**stages_id_delete**](StagesApi.md#stages_id_delete) | **DELETE** /stages/{id} | Delete a stage
[**stages_id_get**](StagesApi.md#stages_id_get) | **GET** /stages/{id} | Get one stage
[**stages_id_put**](StagesApi.md#stages_id_put) | **PUT** /stages/{id} | Update stage details
[**stages_post**](StagesApi.md#stages_post) | **POST** /stages | Add a new stage



## stages_delete

> InlineResponse20010 stages_delete(ids)

Delete multiple stages in bulk

Marks multiple stages as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::StagesApi.new
ids = 'ids_example' # String | Comma-separated stage IDs to delete

begin
  #Delete multiple stages in bulk
  result = api_instance.stages_delete(ids)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling StagesApi->stages_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| Comma-separated stage IDs to delete | 

### Return type

[**InlineResponse20010**](InlineResponse20010.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## stages_get

> GetStages stages_get(opts)

Get all stages

Returns data about all stages.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::StagesApi.new
opts = {
  pipeline_id: 56 # Integer | The ID of the pipeline to fetch stages for. If omitted, stages for all pipelines will be fetched.
}

begin
  #Get all stages
  result = api_instance.stages_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling StagesApi->stages_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pipeline_id** | **Integer**| The ID of the pipeline to fetch stages for. If omitted, stages for all pipelines will be fetched. | [optional] 

### Return type

[**GetStages**](GetStages.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## stages_id_deals_get

> GetStageDeals stages_id_deals_get(id, opts)

Get deals in a stage

Lists deals in a specific stage.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::StagesApi.new
id = 56 # Integer | ID of the stage
opts = {
  filter_id: 56, # Integer | If supplied, only deals matching the given filter will be returned.
  user_id: 56, # Integer | If supplied, filter_id will not be considered and only deals owned by the given user will be returned. If omitted, deals owned by the authorized user will be returned.
  everyone: Pipedrive::NumberBoolean.new, # NumberBoolean | If supplied, filter_id and user_id will not be considered – instead, deals owned by everyone will be returned.
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #Get deals in a stage
  result = api_instance.stages_id_deals_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling StagesApi->stages_id_deals_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the stage | 
 **filter_id** | **Integer**| If supplied, only deals matching the given filter will be returned. | [optional] 
 **user_id** | **Integer**| If supplied, filter_id will not be considered and only deals owned by the given user will be returned. If omitted, deals owned by the authorized user will be returned. | [optional] 
 **everyone** | [**NumberBoolean**](.md)| If supplied, filter_id and user_id will not be considered – instead, deals owned by everyone will be returned. | [optional] 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

[**GetStageDeals**](GetStageDeals.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## stages_id_delete

> InlineResponse20011 stages_id_delete(id)

Delete a stage

Marks a stage as deleted.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::StagesApi.new
id = 56 # Integer | ID of the stage

begin
  #Delete a stage
  result = api_instance.stages_id_delete(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling StagesApi->stages_id_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the stage | 

### Return type

[**InlineResponse20011**](InlineResponse20011.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## stages_id_get

> GetOneStage stages_id_get(id)

Get one stage

Returns data about a specific stage.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::StagesApi.new
id = 56 # Integer | ID of the stage

begin
  #Get one stage
  result = api_instance.stages_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling StagesApi->stages_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the stage | 

### Return type

[**GetOneStage**](GetOneStage.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## stages_id_put

> GetAddUpdateStage stages_id_put(id)

Update stage details

Updates the properties of a stage.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::StagesApi.new
id = 56 # Integer | ID of the stage

begin
  #Update stage details
  result = api_instance.stages_id_put(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling StagesApi->stages_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the stage | 

### Return type

[**GetAddUpdateStage**](GetAddUpdateStage.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## stages_post

> GetAddUpdateStage stages_post

Add a new stage

Adds a new stage, returns the ID upon success.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::StagesApi.new

begin
  #Add a new stage
  result = api_instance.stages_post
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling StagesApi->stages_post: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**GetAddUpdateStage**](GetAddUpdateStage.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json

