# Pipedrive::TeamsApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**teams_get**](TeamsApi.md#teams_get) | **GET** /teams | Get all teams
[**teams_id_get**](TeamsApi.md#teams_id_get) | **GET** /teams/{id} | Get a single team
[**teams_id_put**](TeamsApi.md#teams_id_put) | **PUT** /teams/{id} | Update a team
[**teams_id_users_delete**](TeamsApi.md#teams_id_users_delete) | **DELETE** /teams/{id}/users | Delete users from a team
[**teams_id_users_get**](TeamsApi.md#teams_id_users_get) | **GET** /teams/{id}/users | Get all users in a team
[**teams_id_users_post**](TeamsApi.md#teams_id_users_post) | **POST** /teams/{id}/users | Add users to a team
[**teams_post**](TeamsApi.md#teams_post) | **POST** /teams | Add a new team
[**teams_user_id_get**](TeamsApi.md#teams_user_id_get) | **GET** /teams/user/{id} | Get all teams of a user



## teams_get

> Teams teams_get(opts)

Get all teams

Returns data about teams within the company

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
opts = {
  order_by: 'id', # String | Field name to sort returned teams by
  skip_users: Pipedrive::NumberBooleanDefault0.new # NumberBooleanDefault0 | When enabled, the teams will not include IDs of member users
}

begin
  #Get all teams
  result = api_instance.teams_get(opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **order_by** | **String**| Field name to sort returned teams by | [optional] [default to &#39;id&#39;]
 **skip_users** | [**NumberBooleanDefault0**](.md)| When enabled, the teams will not include IDs of member users | [optional] 

### Return type

[**Teams**](Teams.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## teams_id_get

> Teams teams_id_get(id, opts)

Get a single team

Returns data about a specific team

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
id = 56 # Integer | ID of the team
opts = {
  skip_users: Pipedrive::NumberBooleanDefault0.new # NumberBooleanDefault0 | When enabled, the teams will not include IDs of member users
}

begin
  #Get a single team
  result = api_instance.teams_id_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the team | 
 **skip_users** | [**NumberBooleanDefault0**](.md)| When enabled, the teams will not include IDs of member users | [optional] 

### Return type

[**Teams**](Teams.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## teams_id_put

> Teams teams_id_put(id)

Update a team

Updates an existing team and returns the updated object

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
id = 56 # Integer | ID of the team

begin
  #Update a team
  result = api_instance.teams_id_put(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the team | 

### Return type

[**Teams**](Teams.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## teams_id_users_delete

> UserIDs teams_id_users_delete(id, users)

Delete users from a team

Deletes users from an existing team

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
id = 56 # Integer | ID of the team
users = 56 # Array<Integer> | List of User IDs

begin
  #Delete users from a team
  result = api_instance.teams_id_users_delete(id, users)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_id_users_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the team | 
 **users** | [**Array&lt;Integer&gt;**](Integer.md)| List of User IDs | 

### Return type

[**UserIDs**](UserIDs.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## teams_id_users_get

> UserIDs teams_id_users_get(id)

Get all users in a team

Returns list of all user IDs within a team

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
id = 56 # Integer | ID of the team

begin
  #Get all users in a team
  result = api_instance.teams_id_users_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_id_users_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the team | 

### Return type

[**UserIDs**](UserIDs.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## teams_id_users_post

> UserIDs teams_id_users_post(id, users)

Add users to a team

Adds users to an existing team

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
id = 56 # Integer | ID of the team
users = 56 # Array<Integer> | List of User IDs

begin
  #Add users to a team
  result = api_instance.teams_id_users_post(id, users)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_id_users_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the team | 
 **users** | [**Array&lt;Integer&gt;**](Integer.md)| List of User IDs | 

### Return type

[**UserIDs**](UserIDs.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## teams_post

> Teams teams_post(name, manager_id, opts)

Add a new team

Adds a new team to the company and returns the created object

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
name = 'name_example' # String | The Team name
manager_id = 56 # Integer | The Team manager ID
opts = {
  description: 'description_example', # String | The Team description
  users: nil # Array | IDs of the Users that belong to the Team
}

begin
  #Add a new team
  result = api_instance.teams_post(name, manager_id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| The Team name | 
 **manager_id** | **Integer**| The Team manager ID | 
 **description** | **String**| The Team description | [optional] 
 **users** | [**Array**](Array.md)| IDs of the Users that belong to the Team | [optional] 

### Return type

[**Teams**](Teams.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## teams_user_id_get

> Teams teams_user_id_get(id, opts)

Get all teams of a user

Returns data about all teams which have specified user as a member

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::TeamsApi.new
id = 56 # Integer | ID of the user
opts = {
  order_by: 'id', # String | Field name to sort returned teams by
  skip_users: Pipedrive::NumberBooleanDefault0.new # NumberBooleanDefault0 | When enabled, the teams will not include IDs of member users
}

begin
  #Get all teams of a user
  result = api_instance.teams_user_id_get(id, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling TeamsApi->teams_user_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 
 **order_by** | **String**| Field name to sort returned teams by | [optional] [default to &#39;id&#39;]
 **skip_users** | [**NumberBooleanDefault0**](.md)| When enabled, the teams will not include IDs of member users | [optional] 

### Return type

[**Teams**](Teams.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

