# Pipedrive::UsersApi

All URIs are relative to *https://api.pipedrive.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**users_find_get**](UsersApi.md#users_find_get) | **GET** /users/find | Find users by name
[**users_get**](UsersApi.md#users_get) | **GET** /users | Get all users
[**users_id_blacklisted_emails_get**](UsersApi.md#users_id_blacklisted_emails_get) | **GET** /users/{id}/blacklistedEmails | List blacklisted email addresses of a user
[**users_id_blacklisted_emails_post**](UsersApi.md#users_id_blacklisted_emails_post) | **POST** /users/{id}/blacklistedEmails | Add blacklisted email address for a user
[**users_id_followers_get**](UsersApi.md#users_id_followers_get) | **GET** /users/{id}/followers | List followers of a user
[**users_id_get**](UsersApi.md#users_id_get) | **GET** /users/{id} | Get one user
[**users_id_permissions_get**](UsersApi.md#users_id_permissions_get) | **GET** /users/{id}/permissions | List user permissions
[**users_id_put**](UsersApi.md#users_id_put) | **PUT** /users/{id} | Update user details
[**users_id_role_assignments_delete**](UsersApi.md#users_id_role_assignments_delete) | **DELETE** /users/{id}/roleAssignments | Delete a role assignment
[**users_id_role_assignments_get**](UsersApi.md#users_id_role_assignments_get) | **GET** /users/{id}/roleAssignments | List role assignments
[**users_id_role_assignments_post**](UsersApi.md#users_id_role_assignments_post) | **POST** /users/{id}/roleAssignments | Add role assignment
[**users_id_role_settings_get**](UsersApi.md#users_id_role_settings_get) | **GET** /users/{id}/roleSettings | List user role settings
[**users_me_get**](UsersApi.md#users_me_get) | **GET** /users/me | Get current user data
[**users_post**](UsersApi.md#users_post) | **POST** /users | Add a new user



## users_find_get

> Users users_find_get(term, opts)

Find users by name

Finds users by their name.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
term = 'term_example' # String | Search term to look for
opts = {
  search_by_email: Pipedrive::NumberBooleanDefault0.new # NumberBooleanDefault0 | When enabled, term will only be matched against email addresses of users. Default: false
}

begin
  #Find users by name
  result = api_instance.users_find_get(term, opts)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_find_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| Search term to look for | 
 **search_by_email** | [**NumberBooleanDefault0**](.md)| When enabled, term will only be matched against email addresses of users. Default: false | [optional] 

### Return type

[**Users**](Users.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## users_get

> Users users_get

Get all users

Returns data about all users within the company

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new

begin
  #Get all users
  result = api_instance.users_get
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_get: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**Users**](Users.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## users_id_blacklisted_emails_get

> users_id_blacklisted_emails_get(id)

List blacklisted email addresses of a user

Lists blacklisted email addresses of a specific user. Blacklisted emails are such that will not get synced in to Pipedrive when using the built-in Mailbox.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user

begin
  #List blacklisted email addresses of a user
  api_instance.users_id_blacklisted_emails_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_blacklisted_emails_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## users_id_blacklisted_emails_post

> users_id_blacklisted_emails_post(id, address)

Add blacklisted email address for a user

Add blacklisted email address for a specific user.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user
address = 'address_example' # String | Email address to blacklist (can contain \\\\\\\\* for wildcards, e.g. \\\\\\\\*@example.com, or john\\\\\\\\*@ex\\\\\\\\*.com)

begin
  #Add blacklisted email address for a user
  api_instance.users_id_blacklisted_emails_post(id, address)
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_blacklisted_emails_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 
 **address** | **String**| Email address to blacklist (can contain \\\\\\\\* for wildcards, e.g. \\\\\\\\*@example.com, or john\\\\\\\\*@ex\\\\\\\\*.com) | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## users_id_followers_get

> UserIDs users_id_followers_get(id)

List followers of a user

Lists followers of a specific user.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user

begin
  #List followers of a user
  result = api_instance.users_id_followers_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_followers_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 

### Return type

[**UserIDs**](UserIDs.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## users_id_get

> User users_id_get(id)

Get one user

Returns data about a specific user within the company

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user

begin
  #Get one user
  result = api_instance.users_id_get(id)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 

### Return type

[**User**](User.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## users_id_permissions_get

> users_id_permissions_get(id)

List user permissions

List aggregated permissions over all assigned permission sets for a user

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user

begin
  #List user permissions
  api_instance.users_id_permissions_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_permissions_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## users_id_put

> User users_id_put(id, active_flag)

Update user details

Updates the properties of a user. Currently, only active_flag can be updated.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user
active_flag = true # Boolean | Whether the user is active or not. false = Not activated, true = Activated

begin
  #Update user details
  result = api_instance.users_id_put(id, active_flag)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_put: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 
 **active_flag** | **Boolean**| Whether the user is active or not. false &#x3D; Not activated, true &#x3D; Activated | [default to true]

### Return type

[**User**](User.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json


## users_id_role_assignments_delete

> users_id_role_assignments_delete(id, role_id)

Delete a role assignment

Delete a role assignment for a user

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user
role_id = 56 # Integer | ID of the role

begin
  #Delete a role assignment
  api_instance.users_id_role_assignments_delete(id, role_id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_role_assignments_delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 
 **role_id** | **Integer**| ID of the role | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## users_id_role_assignments_get

> users_id_role_assignments_get(id, opts)

List role assignments

List role assignments for a user

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user
opts = {
  start: 0, # Integer | Pagination start
  limit: 56 # Integer | Items shown per page
}

begin
  #List role assignments
  api_instance.users_id_role_assignments_get(id, opts)
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_role_assignments_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 
 **start** | **Integer**| Pagination start | [optional] [default to 0]
 **limit** | **Integer**| Items shown per page | [optional] 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## users_id_role_assignments_post

> users_id_role_assignments_post(id, role_id)

Add role assignment

Add role assignment for a user

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user
role_id = 56 # Integer | ID of the role

begin
  #Add role assignment
  api_instance.users_id_role_assignments_post(id, role_id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_role_assignments_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 
 **role_id** | **Integer**| ID of the role | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: Not defined


## users_id_role_settings_get

> users_id_role_settings_get(id)

List user role settings

List settings of user's assigned role

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
id = 56 # Integer | ID of the user

begin
  #List user role settings
  api_instance.users_id_role_settings_get(id)
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_id_role_settings_get: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| ID of the user | 

### Return type

nil (empty response body)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## users_me_get

> UserMe users_me_get

Get current user data

Returns data about an authorized user within the company with bound company data: company ID, company name, and domain. Note that the 'locale' property means 'Date and number format' in the Pipedrive settings, not the chosen language.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new

begin
  #Get current user data
  result = api_instance.users_me_get
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_me_get: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**UserMe**](UserMe.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## users_post

> User users_post(name, email, active_flag)

Add a new user

Adds a new user to the company, returns the ID upon success.

### Example

```ruby
# load the gem
require 'pipedrive-openapi-client'
# setup authorization
Pipedrive.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['api_token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api_token'] = 'Bearer'

  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = Pipedrive::UsersApi.new
name = 'name_example' # String | Name of the user
email = 'email_example' # String | Email of the user
active_flag = true # Boolean | Whether the user is active or not. false = Not activated, true = Activated

begin
  #Add a new user
  result = api_instance.users_post(name, email, active_flag)
  p result
rescue Pipedrive::ApiError => e
  puts "Exception when calling UsersApi->users_post: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Name of the user | 
 **email** | **String**| Email of the user | 
 **active_flag** | **Boolean**| Whether the user is active or not. false &#x3D; Not activated, true &#x3D; Activated | [default to true]

### Return type

[**User**](User.md)

### Authorization

[api_key](../README.md#api_key), [oauth2](../README.md#oauth2)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded
- **Accept**: application/json

